(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    169874,       3831]
NotebookOptionsPosition[    164033,       3739]
NotebookOutlinePosition[    164371,       3754]
CellTagsIndexPosition[    164328,       3751]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Guidelines for studying kinetic models in Mathematica",
 FontSize->18]], "Text",
 CellChangeTimes->{{3.47453358752796*^9, 
  3.474533605742178*^9}},ExpressionUUID->"0ac3f28d-2bb9-4093-bfcb-\
64110010a4dc"],

Cell[TextData[StyleBox["A kinetic model has:\n- differential equations, the \
mass balances for all the variable species\n- initial conditions, \
concentrations of the variable species at the first time point\n- kinetic \
parameters, enzyme properties\n- environmental characterization, so-called \
boundary conditions, concentrations of fixed species\n\nAs an example we \
take, a linear pathway with three enzymes and two variable metabolite \
concentrations, X and Y, and two fixed boundary metabolites, S and P",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474533610471737*^9, 
  3.4745337554875393`*^9}},ExpressionUUID->"31c067f0-f0b3-442a-a459-\
d06092c0ab9c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"odes", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{"v1", "-", "v2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{"v2", "-", "v3"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rateqs", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"v1", "\[Rule]", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"V1", "*", "s"}], "K1s"], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"x", "[", "t", "]"}], 
           RowBox[{"s", " ", "Keq1"}]]}], ")"}]}], 
       RowBox[{"1", "+", 
        FractionBox["s", "K1s"], "+", 
        FractionBox[
         RowBox[{"x", "[", "t", "]"}], "K1x"]}]]}], ",", 
     RowBox[{"v2", "\[Rule]", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"V2", "*", 
          RowBox[{"x", "[", "t", "]"}]}], "K2x"], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"y", "[", "t", "]"}], 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], " ", "Keq2"}]]}], ")"}]}], 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"x", "[", "t", "]"}], "K2x"], "+", 
        FractionBox[
         RowBox[{"y", "[", "t", "]"}], "K2y"]}]]}], ",", 
     RowBox[{"v3", "\[Rule]", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"V3", "*", 
          RowBox[{"y", "[", "t", "]"}]}], "K3y"], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["p", 
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], " ", "Keq3"}]]}], ")"}]}], 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"y", "[", "t", "]"}], "K3y"], "+", 
        FractionBox["p", "K3p"]}]]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"parm", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"enzyme", " ", "1"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"V1", "\[Rule]", "10"}], ",", 
     RowBox[{"K1s", "\[Rule]", "1"}], ",", 
     RowBox[{"Keq1", "\[Rule]", "100"}], ",", 
     RowBox[{"K1x", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"enzyme", " ", "2"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"V2", "\[Rule]", "20"}], ",", 
     RowBox[{"K2x", "\[Rule]", "5"}], ",", 
     RowBox[{"Keq2", "\[Rule]", "5"}], ",", 
     RowBox[{"K2y", "\[Rule]", "0.1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"enzyme", " ", "3"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"V3", "\[Rule]", "50"}], ",", 
     RowBox[{"K3y", "\[Rule]", "1"}], ",", 
     RowBox[{"Keq3", "\[Rule]", "20"}], ",", 
     RowBox[{"K3p", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"boundary", " ", "conditions"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"s", "\[Rule]", "5"}], ",", " ", 
     RowBox[{"p", "\[Rule]", "0.1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", "5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vars", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4745337581385593`*^9, 3.474534041763208*^9}, {
  3.474534097886312*^9, 3.474534099925931*^9}, {3.474534184849457*^9, 
  3.474534192235112*^9}},ExpressionUUID->"53636d0a-a059-4b7c-9eea-\
5a1b59d15d92"],

Cell[TextData[StyleBox["Check whether all parameters have a value",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534126387635*^9, 
  3.474534145184894*^9}},ExpressionUUID->"320754d7-d5eb-4b23-a617-\
39cf16656877"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"rateqs", "/.", "parm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"odes", "/.", "rateqs"}], "/.", "parm"}]}], "Input",
 CellChangeTimes->{{3.474534086271529*^9, 
  3.4745341235239687`*^9}},ExpressionUUID->"d956772e-51e5-40ec-a083-\
d9ec6fa87cf4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v1", "\[Rule]", 
    FractionBox[
     RowBox[{"50", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"x", "[", "t", "]"}], "500"]}], ")"}]}], 
     RowBox[{"6", "+", 
      RowBox[{"x", "[", "t", "]"}]}]]}], ",", 
   RowBox[{"v2", "\[Rule]", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"x", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"y", "[", "t", "]"}], 
         RowBox[{"5", " ", 
          RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"x", "[", "t", "]"}], "5"], "+", 
      RowBox[{"10.`", " ", 
       RowBox[{"y", "[", "t", "]"}]}]}]]}], ",", 
   RowBox[{"v3", "\[Rule]", 
    FractionBox[
     RowBox[{"50", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["0.005000000000000001`", 
         RowBox[{"y", "[", "t", "]"}]]}], ")"}], " ", 
      RowBox[{"y", "[", "t", "]"}]}], 
     RowBox[{"1.1`", "\[VeryThinSpace]", "+", 
      RowBox[{"y", "[", "t", "]"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.474534092078047*^9, 3.474534121738799*^9}, 
   3.4745342288337593`*^9, 3.474536129482747*^9, 3.474536163604805*^9, 
   3.474538455875043*^9, 
   3.6004053604937353`*^9},ExpressionUUID->"42f4d63e-7819-45e8-9937-\
86375327ee4b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     FractionBox[
      RowBox[{"50", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"x", "[", "t", "]"}], "500"]}], ")"}]}], 
      RowBox[{"6", "+", 
       RowBox[{"x", "[", "t", "]"}]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"x", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"y", "[", "t", "]"}], 
          RowBox[{"5", " ", 
           RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"x", "[", "t", "]"}], "5"], "+", 
       RowBox[{"10.`", " ", 
        RowBox[{"y", "[", "t", "]"}]}]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"50", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["0.005000000000000001`", 
           RowBox[{"y", "[", "t", "]"}]]}], ")"}], " ", 
        RowBox[{"y", "[", "t", "]"}]}], 
       RowBox[{"1.1`", "\[VeryThinSpace]", "+", 
        RowBox[{"y", "[", "t", "]"}]}]]}], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"x", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"y", "[", "t", "]"}], 
          RowBox[{"5", " ", 
           RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"x", "[", "t", "]"}], "5"], "+", 
       RowBox[{"10.`", " ", 
        RowBox[{"y", "[", "t", "]"}]}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.474534092078047*^9, 3.474534121738799*^9}, 
   3.4745342288337593`*^9, 3.474536129482747*^9, 3.474536163604805*^9, 
   3.474538455875043*^9, 
   3.600405360496831*^9},ExpressionUUID->"d29c5324-1c00-4145-9038-\
4944620ca831"]
}, Open  ]],

Cell[TextData[StyleBox["The time-dependent solution of the concentrations",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534148729026*^9, 
  3.474534158872654*^9}},ExpressionUUID->"5b69a184-6a41-4a4d-84f5-\
96d1885d7f8b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"odes", "/.", "rateqs"}], "/.", "parm"}], ",", "init"}], "]"}],
     ",", "vars", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.474534161027247*^9, 
  3.474534232633519*^9}},ExpressionUUID->"b4f16bb4-de9b-4f81-8ecd-\
76b9d93c3f2d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"y", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "100.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.474534205778372*^9, 3.474534233307005*^9}, 
   3.474536129622764*^9, 3.474536163760508*^9, 3.474538457137353*^9, 
   3.600405361281014*^9},ExpressionUUID->"c110915d-28b0-4541-ae58-\
c858ca45b96f"]
}, Open  ]],

Cell[TextData[StyleBox["A plot of the dynamics of the concentrations",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534348999889*^9, 
  3.4745343562726793`*^9}},ExpressionUUID->"6d6dff65-a952-4937-a551-\
de4afdd2e4e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", "tsol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], ",", " ", 
      
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<concentrations\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.474534237030816*^9, 
  3.474534337924259*^9}},ExpressionUUID->"adfdc4b0-b91a-4e2b-b930-\
8b2d728cd291"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwV2Hk4VG0UAHD7OnPt+zIzRpaIFpGSe7JVEiW0SbKEQkoSqXyRXVkjhYiK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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.01], LineBox[CompressedData["
1:eJwV1nc8Vl8YAHB7y97r5ZUGkVI0zxNRZCVESSWbZGQUxY8KhSQhZSSVUFSU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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Gill Sans Light", FontSize -> 16},
  Frame->True,
  FrameLabel->{{
     FormBox["\"concentrations\"", TraditionalForm], None}, {
     FormBox["\"time\"", TraditionalForm], None}},
  Method->{},
  PlotRange->{{0, 7}, {0, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47453425483462*^9, {3.4745343134958*^9, 3.474534338961828*^9}, 
   3.4745361297572536`*^9, 3.474536163853672*^9, 3.474538458632216*^9, 
   3.600405361330306*^9},ExpressionUUID->"1dc73e5d-a5aa-403f-9ca9-\
1b7380102f86"]
}, Open  ]],

Cell[TextData[StyleBox["Plot the rates",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4745347252340107`*^9, 
  3.474534727185828*^9}},ExpressionUUID->"f0a21c98-9f37-4a80-9867-\
ff5af604e80c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"v1", ",", "v2", ",", "v3"}], "}"}], "/.", "rateqs"}], "/.", 
      "parm"}], "/.", "tsol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}], ",", "All"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], ",", " ", 
      
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<rates\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.474534237030816*^9, 3.474534337924259*^9}, {
  3.4745347422020187`*^9, 3.4745347952555637`*^9}, {3.474538449947352*^9, 
  3.474538450408195*^9}},ExpressionUUID->"f71ee0d7-2882-4837-bc54-\
b0e6a0c0665d"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwV13k4VF0YAHB79vXOGPuMEUJkSaS6b7ZKEgqRJFkjCYXSRkWhkLIVFSFL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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.01], LineBox[CompressedData["
1:eJwV13c8lV8YAHAje91hz8sVhZRIRM6TVUr5ZSWhQqEhklBaJDIykiQSEZWR
QhlZKXsTSUlG2eGSUfzO+8+9n+/nc+59z3nOc877PLKO58xPsDAxMXniD+I7
6aoju5pzmJ678qVd0U5RetUdNNNDNDcUoZ7Tz6hwR2sfywJpND+0R1oqWtH3
GkqqiJBho91G/oX3eMWvRyGVaec7ay6RSOqB8VdEv4e+8j9a/dsdgzJWGY3m
LAnozE7vs39kHqCM4W075/VT0evO72kMg0SULKp9WV48HS2fNu2bcUlGu3y4
TTaLZSLDpuj1C92pyHZjXPO5hznoV/zuSoZbGjq6jWL0hZKHwp3/2c2tpCPh
0fa77HOvUMeKa+xvmWfI99uZkSS+N+hijfSW6bznyELZj11zfxESv9vZMGmQ
hR6eU2bZ+aoElTmEukx0ZSMhp/KTzFCGHJWAddwlF5Hv6BYIX6lALCuXWhj+
L1FB5fFtLrOVqPO7lRTDKA+90Wnm2RrwHvlm8RTNdr9CvT83rnivfER7Y0bY
Zx+/RtImkQdrxmqRpG+l5YxbPrr38TOPJVMDmrJPTP29tQBdY32f8As1oQoD
n9/TKwUorsoO3mW3oJiN5nrT1YXojpDfR1BsQ84Cm8KnIt6gYQmpoPy77Yjj
yw/FSZkipPByB0pv7EI9Fe+8J34VofLVcfqn5G70/Gn8+/G8YvT4ycCNsMTP
yD/cizx+qQTlmPfGMNV8QQfOHzg6ZlCKyhISrFrp3xDNZmP2KO87ZBmIEpeP
fEezO9et/Op6hy6G7d7iWD2Aqun9e349KkMM2YnvM/sHURxXcdxPl3LEXmpp
lbgyhPJ99p73Eq1AnWUlzSdbR1Di2HaxOf8KxC2Ramfd8gsF2a+vOD9QgQrH
P1pbr4wh91aKy6xRJbpZEqYkcmgSHTJg4j//vBJFtd/jHh6aRlA4mT/DX4XK
wMxb12IGURJrWWa6q5DIXLFtvRMDrfAXPvPQfY+CnnVztVAW0NCNJ//9fvwe
STx+zr76+Q8qdLn6aNqtGtUWO08tPl1BtuoaO6ZWPqCqrafkYYgZDJ7KDpw9
9hE9sx/l5/nJAipiAiGT1R/R8k+9hcBBVhAK/6t6dmMNMqnO5OToXgerq6Nd
ExE1yH3pZ7ZJORv89Oz2PzNbg2JPf7E9n8AOrUPV9AnrWrRdZfmeggsHvD30
qv50SS1qUCsxuSPPCSn1yZ7jMnVokTH6YX87JzDiC5T6w+vQbL/1TuoVLjB2
aRhsX6pDR2leTyWFueHBtoHEjyfrUcrDORWHR9wwwfrHqrijHu1hyfXjE+EB
1M4rkAMN6IfH4ouQGzwQ81iuNiW7AfUfeLler58Hht21btwTb0T244F2CWq8
oLXzwI7bwY0oKmZP4rIfL4TxOM/5MxqR1welw+lFvPDts1+Wx/Em5NyituPD
DC+oZUaecG5uQnwnyt6dpPPBzYvp0jY6zegSi+SEjxkfdBuWdO/LbEaMjOCX
tRf5QInaFoWEWlBPHLsAfwIfXBkYMVEPwHmcHPRoqIgPWnP/sihOt6AHDN/t
7Z/4gIK4HPhUWxGr+MLTPTN8oKMQuyPYuRXZPnu2msnFD3cYz+YutbUi5/wg
f6dt/PD2i0Yrg6MNOdo7knea8MNAVXmWu14bypqOv8pqxw8a0V0nHF+0oaAv
rhrzV/nBwfeYft9AG9JuUx07GskPwUfHpa1F21GY1r9rWsn80LuJucckqB3J
sfzcfOMdP1yrV9mrdrQDabmpGDPm+SEz743Ci3sdaC74jb47qwC0x+uzrm/s
QGnHOPLySQIg72JTKqrdifjEbtcVKQlAPetNVSZqFxp72M66zl4AhHd+obR8
/ITU9fzUd5cKQE7u7S9nVHuR8WJ1peM2EoxRxsL3Hu9FbKzHC7bsIIHixb16
G2J7UUHmVZE/eiR4rMuTMrjUi3bNWLif3UOCmLrwk7YfvqAavYhdLEdIcHEw
cma33Vf0Lkl4f+9VEiTzNASSjb4jyW33z2ZUkkBv52W76w7fUeyIvffjDyTo
c1feNu3zHUl53Mu+W0cC0fawkcbn3xGfd8RX1zYSRMebmoSQBtC3Lw8utHwn
QeD6Zv61LwNo40aD8bhVErigtgcT5wdRbO8ua0tNMjClLhR/CRtExn6LDXHa
ZIhfJ9lXnzaIuOldnzt1yVBbd1L62adBJB8q3W9gQIYNln9TT+wYQk/d3tlN
mZHhl6ti1jfmYaTZGnzqsisZTsVcKWuNGkEdR9sMn8aRgWU+tb/82Qg6MjHi
5/aADAmHaplyq0aQwoZ3MhsTyVAvSTWIYIyg0iT5rqQUMihnZNaY2PxEfrnO
IfZZZJgo6WitkvmFop4NTu2oJIP78MbB/JxRFBURqB3ziwzfHT5zVtaNIiF+
dmbZcTJY9ISoNg2NonCrT7ZZk2TQavjpNyw+hma3x/W9nSUDa146STh4DHly
Pit+9hev119Wz+foODpIno2ZFqBAJVXsgTZpEjU+nz6zWYMCGhG1ZUbKk6hu
r2SxrSYFnrL7Dh00nkR33wjqBGpRIHzp0+ZT/pNodWVutEGXAtb9sR8Tfk2i
4xbM3rpGFBh7TmKsVEwhh19fJ5OsKMAte1OxX+s3Gv/wlnb1AgVqdaM3XzX6
jQrXbzHQukiBWzaPtkuZ/0Zx+dcdf/tQgCXq7e4jp/H4C/WptpcpsLw64dKd
9Bs9frrZRySAAuN9VpktLDMo+MGLHo1ICjTGK26saJxBDzLE9EmZFAjN11A7
+nkGic/2Ckc+o8Ce1l3aq8MzyPK6nTbvCwpUc9iZ6K7NIOOk5x7MORQovRjl
9lZtFtXe+DPS/ZoC2ZZLz17GzaI9l4Z7NMspcIfUoJRybA6VdnPYNnRSoGi7
VMEB9zmUOuzfqP6JAkMO59Dfy3NocWItIqGbAjrZVMtD9+dQtmA0h1MvBX6Z
2F3ha55DHheLBL/3U8AgcLLFT4eBTFilwsPHKLA4L+BtLjyPfoQxGZetUoAu
5bi2Rp9HEmwV/Yw1ChwwzL+drTaP0qMKeJWYqZAeY/OIc/88Co+/rRjFSgXz
zSk1ZYHzqO9EW+w+Tipku24VV56ZR2dPLv28TqaC4xfLctbGBXR1yvntjBwV
uB8OnPX8vIDEivn2LtGp8MrWXbJ/ZAHNpVnmrclTgbU32K+Y+Q+yMX7AzqVI
hbSeYnXP7X9Q6o42Bp8yFUa6aJnfUv+gqy+GZX9spcKp1omoIr9FJM+4v+/d
LipQovyQYvAiknNmGKXqU6HYjH0qNnYRFfEd3nXLgAo8LTL7PHIXkSCfPuwz
okJWkzmb4vAi6tk2e71uDxWm6t/6xf63hHg+p4jFm1HB88NNx3OKy6iUe+xs
kB0VpIeM2RfUl1HlxQxXZE+FBhau5/6wjMr0v6UtYq+HiJnbh5eRldaBYdej
VPhcfO96WtgyEh2STgRHKux6+fTR5+ll5BUyHNvkQgXyw9peg7cr6AInk6rT
eSqUFYVera9eQaWKs9/ZvahwusdU7mDbCkqtEJh6hv1BqM3NYWwF2SVkik1d
oIJf1OdFX8m/aIOqbr27DxUGgsaEc67/RYo1vsrm/lTI8+C1EDX5hy4VWMSn
B1GhMYHql239D+Xo83Do38LxrBZP1nf+h9LkChq+YouLbRw/c+0f6shePEwN
ocLNSqPAyoJ/yCbsS/LFUCpYU669PiW3ilpkT/tJR1Jh+fUM9d3KKhI7+NRz
8T4VBL8taptzrSH7LeW8N+KpoMrJdOyn8Bq6mdgjyPWACk52/FnkrWtI4mqg
u0gCns86ZcOTrmtI7Ebx4U2JVHhk5XxBoGsNZaQPJ+k9pkLK5dNjWw4xwU5Z
Ds2VDCpsqeBaDLZngtBBRvGpTCpUrMtk63digitB71o/Y3+PGKJFeDCBe/ub
l4XP8H49tj80epsJ9KKaDpx+QYWEarPqlFIm0NHZdqIihwoxfBqPKHK4rvmP
6Z9kARXkzNtfuG1ghumCvAvXsPPiPIoqVJkh3fpL6AB2q0x2p7sOHu+kFZtW
SAX+rQo8DZbMEDF0WUHhLRVCrUV9A4OZIe6Ic5FICRUCkv8eZEwwQ0aH0ofC
Cir8t+Wtp/IcM6zEfxPircTzq/SKdlxihjNBVMHj2MU/xlpb2VggQT5SnLuK
CrPrP5tlS7OAoWe2rc17fJ6yCvaf/I8FLE8GzA1/wPlU5G7S85oF3lg+u1tT
j+ezV8lNoJgFjvmVbqM2UKGvdzjEuIIFsscUIh2wff/a1eY3ssCjcFk3BvZL
tG939DALvC2+XSnZRAXaR0WjvSKsIEPXMTzWQgWmju9QeokVxn0U7+R34HwY
LUu5dIMVtjow2/zD5mJKYtEOYYWsrY8+GXXi87fpcHXBPVaIv+I014W9Prht
d+5LVvgUyP96tosKe3WqDqSOsMLkAG+gdA8V7j55Yhdivg5qWcav7+qjgmjx
jXfGh9dB8ry21w3sxNaj0mzH1oFqdAe9EvvpP4nvN86ug2BOegX6SsX1YqzT
5ZB1YLqpa1L7G14vT9Ap97J1kJFkZCn3nQoKF076WiqxwQXatS0fBqmwaUe/
RfIWNuC+ofl0CVuDyWbzmCYb7NvxZHTTEBX0w01GrhmwgX3N0d572A5pKpYv
7Njge06jq9MwFeI6ZzezRLLhuILz/AgV2LZd+5k7xwZyAxSZhVEq8K78qVpe
YoN3uQ8z5cdwPCo9HhkxsUNgVTGbBTZtv6PVF152SNpvrpOLrXvC6D27Ajt8
ZBGOPzFOhQv3eJLtbdhBUHZlR/0EFYbm71vzvGMHg+l8uwvTVEjdpe719T07
VBnek07BPhrRHJlbzw4OToavmrB75dnqLHrYYTB/2kzhNxXaLM7rJM6xQ+/G
W25d2GV5prRNShyQvVqsqzxLhftnmccO3OcAA+v7mYUMKlgWJbLLPuKAPetL
Vr9iU9i06HNpHHDVylGFbZ4KdxLd7e6/4gDbuVF+C+ybDV+a+5s4YKY5eH4C
22Nj4WuPdZwwt2H8tNgfvN/Dp67EeHJC89UhYeslKhhfoWcZ+nLCgOJ9bl9s
faG+3oWrnNDpJd/3AHuH0X6tI+GcwHz/kthXbKX0zXP0DE6YOKrH7LiM7+8T
DNeCPk6wn/z68MQKvj+Grlj27OaCW4er+i3/UaHWXzMw9AAXeL7ubjqPXS04
nadrxQWFV6qTorBLDY8JpDhyQdjdusEG7Kw0/Xo33Ee0JTnx7lqlQoQzB6y8
4oIr1Vd/rV+jwoGhKGVpaW7orleL7mUShEbloU47eW5YPdiiOoe9z2v71YdK
3LA5y62Ah1kQ9rB8axXdzg1kt4Yrutj6NOWL1P+4ofbqs3+J2NvsPlRwBnCD
kd9a42EWQZDsXLKaG+aG2VAu3fesgpAgsX9NbYIbNDyVZD9jizk9zvSY5YaA
iY6ZKWzhWeOVyVX8fzoC1uLrBIFEin38C/c1EVv3q3hgs5qqjn814YFQIwZN
lE0Qxt47Xq/N5gGSns+Dw+yCIBPdc+pOPg84fasqdMe2dDhgZVnCA5S68LJA
7LJFbaXvtTwgb3bgTjZ2zCZy559BHmBbaldj4hAEnfvliorivPDvRHRKCnb4
KcmWoFu84N35OaWLUxAqt8cU7YvghfObTu/8hb2wjjONHMsLTU82fFzGPpY8
55uUwgucn5KTZbgEQaOzXq6glBd8Oru8XLG/7vS7ODTLC26vRF4uYKuSP0kZ
HOWDu7dM19h4BGEkYiTg3gk+EDPoNRXCTuL+8/PnaT64J/Y7TB6bd53oq3Bf
PnivPv5NH3ts4bDxp2g+2P/58eer2Ol9X93dqvmgs6hyGwNbMnO4PHIjP3RO
TrZ08gpCp/yC/I/N/HBcn+/UD+ywFPZQDU1+uEgy/zONvZygaPlZnx/8doaN
c/MJQk+E2y853EeBx6AOYN/1miQV3uGH7e+Lb2Vic6P5431z/ODO3SfpwS8I
vrs2cBYu84NV9d1tV7BHDI7kRDILgM2pJQjFrtpTuawvIADV+Vxb0rAvmUfc
fYb7pOH4bo9u7PET6z9cPC4AdwbdQ3QEcD6GW20gtwjAo4p/dsvYOyJDmse6
BKCwWGaIjSQImdElF6r7BCDPK+4oGftmnGylz5gAlJUEqG/Alm5dUJlmIcGJ
EZ//rLA/fa76YCVNAoFbu92ysXdP2v6RsyLBoqKijRVZEB4JBnZcsyEBb+be
/UexGTovcvtwXzXieFbLDftx6IpLnCMJaof7f/tjLysm9nB5kED58O7fT7Cz
HL8W/Q4lQf07tc2/sUk9R/3LKkjACPuQeIMiCCfXgm0kqkkAXLYuodilCi81
fGtI4Lxfe+NdbDdvpkm1ZhL8vd4Tk4ZdRUmxT/+C+7LfD/99xL6w/4de+AIJ
rPSf7OCm4v2pcma2VSHD8EWICsX+vatX/MpmMrRc3NcUjc1RaabxeCsZLHmf
sT7A1izf4TKiRYYT26/bZWDHlpCazhuR4Qsklr/HNssvjQ9zIIP0jt3mK9gf
0wW3vIsig6z97cgTgoLwTT7U5PtdMjSfOcJ8Bnv+yZoj630yuNzXPXseWz51
7J5JEhl8LYa2XsMOeFSx0vWMDPzcVV7x2Hr3z9RMVZHh4P57fXXYBSHVDrR5
MvBMMF3aIIT3c2+DaPAiGfRYc1+qYifwtrdPrpBhMUlwQAP7elS/cQkLBbrs
6Jt3YZvGL6tak3CfMiN24zD2j4wta2HKFDCfZmG5jc1fk5j85zgF8qdCUwex
mW8/OexwggLqAa5So9iMvc+pH1wpwJSQFDOF/bn5TXDMOQo8Pi1/Zgk77VP7
uU1XcB8nRenjF8b5N8IJTvEUcI+tKtHCPsnm/b25mQIJndcSQ7DFZeq6V9rw
77/aSEdgN2tJtWzoooCLGeNhNLbmmQ/vAr7gvuNdYGgCNnuH0EPNX7hv+n1l
WxZ2+uNCq0e4DzG0PPOxGXtIZ7H+rAauizwrpkgiguB0/nIBL64r/cLshUKx
Nbd+K9iYhOuupqmYCGzuWSg0xnXliIIBXzT2S0/2N9ef4vcGXX/xPvZfj+i3
jFe4TrBkZKRjx53LKOnDdZLAZapnBXbdmY7KLPzeKBbgqJnDTlTRrKrD74Ey
PYXBBWyPifiqEXxPt99y/ruELXzG4T2NG5+71zYKTKKC4Hh6tDoWz3sduceG
F/uv21qN/2Y8T4GHWvLYm12Um02PC4JKB+/cQexvbjLnsp3xPXY1jGGJHX6G
SuJ3xffMzbXZQ9ijnisHW9wF4bZg84g99hP/hq6D/oKgtVn1hRu2SMzpr9b3
BcEijz/zOvZa6YuJY02CkKE6FZSFnVOeHFHZiu+RjimVXGy7qruqcp2CsMnU
qi0Pu6jmssdgryBMZDtS3mB7te9jnPglCJzPe7wrsX/+HF85xSoEzPHi5V3Y
LRQVHm9tIUjKSzj/F1vv7NnRh7pCkEvmT10lnleTU1OFhKBwv1MLk5gg3PFX
u0kyFoL9Tcl0NmzTEc1/L8yFIG7G9DUfdn3Rrukfp4VAKfi3lzT2h2OHOv57
JARbAuCWHrZGSXyeT4oQSIvG+gB2mlBv5KM0ISj7IeSij32z3s504jkef/AF
GGPrazh+CH4jBNpb/vu2H7uC4+ybslYhEK30/2CHXZIT8FCFVRjcRmb/88Nm
N7USv88uDKk6uVsuYx8cVXzAzC0M667d5L+C/ZPeFPeJJAzX3c9VX8emPhCJ
uS4tDFfXGYqFYJ8OzArp1BYGl5dHT8dhS9h88vb3EIbbb0xK87BPzmcyRryE
oVv9k+Nr7LyYy14HfYThn2URRwH27iaap8JVYRCtCjd9i+2lf/pMa5gwWGSd
rSrDblBhcpLPEIYWb7tjDdiXmZX+a/wqDNYic56D2COGPD0KA8Ig0nOufwj7
v5CJozeGhGHE+/q+EWx5gdxzmuPC8NvNWWYUu1FSI/LxojB8kXArnMKW1tJr
vkAVgaCl6dQl7Cp3c1MpExF4+yviCr84Pk99l/a454sAqxZrgAa2ps8zvsg3
IsDRxgjbhn2c0tOeWywCjE3TsZrYb/dss5+pEIHMGeY0LeyTBdOeF5pEQLuj
qFAXu/KO88NLIyLQGGOYayhOvC8PTN0SFYXVAPM5C+y0Pv/XGRKiIJiu8t0S
u8XnhW+ttCiMX9rUaIWtkMPJyr1eFErWnqYcwu4Qfy8SoSYKFmaR+kewVRnb
d93dKwoOvyvtHLGHn8rGJvuLwjq63p9z2BM3B5ZYr4vCe3a+Pg/sWceUo66B
ojCSPF/uic0kI6usFioK6kYiQV7Y4vdpVVX3ReFd8ut1Ptj/Bcv8Hn4lCva6
pN4r2KUuUqYqo6JAihwYCsV+b/Q1L2pCFHy4XuaEYdfTk0Tmp0Vhwfe1Tzh2
d7/k4LsFUUipPcJxh3j+IclLZuvE4KC8oVQ09oY9EpnnZcSgNYZD/j527Aax
dUVWYnBr08KTVGw7B4WMQRsx2L5VcO8TbPlY9b38dmIwty9umnD+2v4oJ0cx
sG2s1UrH7vwUIMl/Tgyij8+/z8CmBk1oOIWIwfiv/ndZ2DED5Sf4SsQg/LSe
YSF2VMLJmuM0cagrN35bg+1zMcDLny4Oarf4tWuxHcwfydxXEAdO+WNFhFW4
P/k0qohDw73Ut3XYdX5GG7Zri+N+7GVeAzbLYfnbvObiULHb9E4LtrfIj71v
AsXBXsyd8YlYz9y/hbZb4hD0YadLN7Zhi9iTidvisJ077TNhSvDBFdkocbjd
su1dD3bOQsWL8ERx0Drle60X+1dXMq9jgTjUD9T//optG2vfzPtTHOSuG94e
wpZ8zS1xekwc3BkHFwn3t71xqZsUB83jMyeHsZ0FKMy3GHg9CT/1R7DdQz+q
rzFLwN7Kkvmf2AHXNz+YkZSAN88td49jPzvD7PzJXAJ62bsTZ7DPhOW81LCW
gE3xPauEVZ8f+RdzWALUW32OzWK/+lkQZ3ZMAmSeR8nNEfnieKqu9qwEpO/U
TGVgt9p0qJaESABloi7yD/aiYfpScpkEzCm5KP7D9i9JDqyulAAOL1Vfwkxb
E/hGqyUgdPR5LWEOmUjZrQ0S8NK02nUVW3jJ16S6WwIeHrqWvoatnm364Ndv
CeD8bkJmkcDrE2JoqdElISav+TU79mzYVJWVgiS8j365QtibZdT00kZJ+LZo
ZsCB7T/99dj7zZLwkF7bRjisribESlcSrI4/GefEzrzysMfPShL8N6tRebAH
h/V9q4IlYTSFQ10AWz+5OVUpTBI23bTxJfzYxrYp5o4kUJ84viPs0OAp53RP
ErTvPTEmYfe+fNzI+kQSOKDfiozdfnmVZlQmCcE23i5U7CpycV0NQxLYw9Rt
RbBlG4wYmxclYYeQ1X3C12+2ScevSMKy/Y5Ownp/fnm5skhBI+O//aLYxX0i
0lwkKdhe8lpXDPtVhvf5vcpScKTmMkkCO3WnmkTTcSnwLb0YIU087wB34Iqz
FGyE7+WEfxwdHNvoKgUhBeKzhOkB94pvuUvBs5w1KxnstI9Lh+GyFIi03JKg
YaebVcW/jpWCnUezkmSJeB23EE6okYLSS27X5LGzg7zJLpukgSv3VNVG7Ald
+4CgLdLASDYbJazCMJx7oi4N2Y6CJCXs546CXd+1pSHp1U57wpnodbytsTSU
tZAXCKct/ZY5cFQaWBLaZVWwE86eUd0WLQ0HjPY5qhLxlbdMtoiVBo9UiyDC
Yn06pPP3paHGTy+TcPxentmcJGlQmCiZJHxP8XnBhufSMLPVxmczdtTAT13J
93j8q9qbW7CDrZz2sc5Lw/G5yJtbifiZ9dmdWJSGzR2L6YRLTazca1akoXxA
q4bw7M7d0WEsMiCgh7jUse0UlLupJBlg73ELI7z1z6yjvLIMBBXYh2hgf4sP
uGR0XAZSt0ue1MTe1pfyLLhJBtQ9mQa0sUmqrou5rTJgX8C6THjimurung4Z
CPi7SNlBxINeMrShVwb4EosMCQue7pSpH5EB6Sq1DMLL/qz72JlosL5z/Ukd
7M88mpV7xGiwx6O1WRf7o8aDX33iNAjgDhkinG//V8BTkgbmFhuXCUflVjk8
kKFBVJLS+p3YeyzM/o6up4F6s/olwm8TXLeHbaVBhlYZTY+I78aH2U37aPBj
59VjCJsxZ5weuJ8GcQLe3oTNymYTtc1owPrXIpQwu8Xe8HRzGvDK1b0m7O2/
dOrKYRowIm6zAbZ5y6ENm1xoQNZTSiPM6y34JDyABu+7C1t2YbuiigT9mzT4
xDY5QPg915mYxSAaJG4RYhC+9Oj9DefbNIjfoyOqjz1ac/6YbhQNukS/HiX8
UbxNaiKJBppTpycIX6uIiN9XRANjH6VlA+yxrxWxS8U0OCG0ntsQ23plLiqj
lAYHj/CJE1bRtL3NWkGD/LkMbcI9LxQulXykgfsYry/hrffLjyh30oB6p32G
8MjZGWmeaRoIpqh9McI+GCYvUfSbBspeLqOESzMPibjM0mD53t0/hO8OvhN4
P0+Dqa3lVGNsOBzKdPkvDehRsI9wgiH9xxiXLAwI8L4hvF/CKr1eXhYWl2oD
dhP7MaRacURBFtYHat4hPJTN+WVCURaEReIfEPaHUpKAsiyYdW9/STjrBN3f
Qk0Wwpgn+whzv5wx79spCyF2ezT2YNcY3mGaspYF6Ui2r4Qp/K4S12xkQUfR
+idhh+5dmiRbWXBLSJ4hvOA2f3qrvSz8nZNkN8FWiLTrvugkC29TKlQJ3/ys
lLN2ThY2WqdfJbzLveYI+bYskM1yRfcS+dszalwdKgv759rlCOcb8G71CZeF
vZtHVQgriB3k/BopCwJ/J4Ewb3VvfmacLATX2LkS7hGb4oM0WZCUnMon7PFB
sMK9XBbOne422oettGX7C9lKWRCJizlAeDDhcFxnlSzUVBseImzt8ejMjo+y
8KHkjithXYkNYuxNssA2XRpKmNNT53xSryzU/3jYRDhZ0lG+cV4W2lcv7TfF
3qGurOr4RxbiO15bEu40YWxfXJSFsYXhI4Q5fW7tk/8rC0zqmqcIe7Q9P+/P
IgfJH27dIgy35ipUBOSgwW/sHeEf0zftIzbIgU5hi+J+bPn3GXEHjsiBiWbo
KOFmlcW0Pjs5MPKiTRP2jdvz+pSDHFwszmMQbnAbbbl1XA48gz6sET5PUuYq
d5GDov5XQgewy+1zLm++IAefNV4AYdvF/GOkCDko5CfdJbzOke3coztyENDJ
E084p8HqikqUHPwqYEkizJy88GDPXTnQnhh4SjjTSKvj+gM54ON1KSY8H1Ni
NJMuBzd23f1OOGpTlVJ7mRx4NWRtNCPGax3hCqiQg/VS/qqEyw0YP9Wq5CBr
wFid8NRhhfToD3LAOdmsS3jfrVCZg41ycEftuRlh9n5zwdbPcnAqNO4C4ctR
g/+aGHLwNJizhPDJuXVtdUp0ONWrqvMfka/PDZvtVOhQvpSnR9j6+M2G6U10
cJDfqk/YuIX1o5AaHTYVbDQhrPCCpeT4djpsdVuwJjzsyJS+ZECHbuNZT8LO
7Su+G+3pQO/0Sidsd1vnYqkDHWiXojMJW8JlL7NjdFiRy3pB2DBn+ay3Ex32
xPTkEZYPXXKsdKPDlB9/GeHBXX9MD1+kw07WuS7CjnmztNuRdHiV9Z71IPaZ
AIu/e6PpsHTjGzthb4v8bt67dAg9t8BFOGTe+05UHB1abaVIhHO0l1buJ9Gh
idtIkvBS5dqnpy/okE5ZVScc1c4bUV1DB9t7m44TTnhy1vVWHR0Sun86EX5y
odlgTwMdVI2STxIuFI5abmimg2su2xnCfbZU144uOjhL5F0krDgoZvBjEK9X
OSiM8Jb8S9Jpw3SYe069Q3hH0JelEz/pcO52chRhU8Wkl6NjdFj2zL1H+Pxp
mvTMDB0KTF8mE/bXvbH0ao4OwnSlVMJBfD86L8zTgeSVkkY4PvdJ2OIiHfrD
Q54RTr2+zqV4mQ6a9osvCL84eELf/y8d1PNP5BDOl/sopbdKB9F7rS8Jl80p
LK2t0UGBVfs14f8BTi1uVw==
     "]]}, 
   {RGBColor[0, 1, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwV13c81V0YAHAjm+sue9zLFbLKKNE4T0ZlR9GSEKmMpJKiQWWLREZZRSle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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Gill Sans Light", FontSize -> 16},
  Frame->True,
  FrameLabel->{{
     FormBox["\"rates\"", TraditionalForm], None}, {
     FormBox["\"time\"", TraditionalForm], None}},
  Method->{},
  PlotRange->{{0, 5}, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4745347609787416`*^9, 3.474534795629759*^9}, 
   3.4745361298717318`*^9, 3.474536163978359*^9, {3.474538451181612*^9, 
   3.474538460481629*^9}, 
   3.6004053613830423`*^9},ExpressionUUID->"ae519512-dae6-431d-8f38-\
c0e62484fd3e"]
}, Open  ]],

Cell[TextData[{
 StyleBox["To calculate the steady state concentrations we will use the ",
  FontSize->16],
 StyleBox["Mathematica",
  FontSize->16,
  FontSlant->"Italic"],
 StyleBox[" function FindRoot which finds a solution to the steady state \
specification given initial conditions for the concentrations of the variable \
metabolite species.  One should always give initial conditions to findroot \
that are close to the steady state value and one way to do this is to obtain \
them from the time simulation. As at timepoint 5 the system is close to \
steady state, we choose the values at this time point.  We have to give \
initial conditions to FindRoot as {{x[t],1},{y[t],2}}.  This we can automate \
by,",
  FontSize->16]
}], "Text",
 CellChangeTimes->{{3.474534360423442*^9, 
  3.474534517594297*^9}},ExpressionUUID->"816300db-572f-4938-9307-\
1acefac4218f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"vars", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"vars", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", "5", "]"}], "/.", "tsol"}], 
       ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "vars", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.474534518921184*^9, 
  3.474534586068171*^9}},ExpressionUUID->"6a311020-26eb-4cf2-938e-\
4ef248420e59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], ",", "3.864981325264804`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], ",", "0.12841354120422668`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.474534557356555*^9, 3.4745345868403683`*^9}, 
   3.47453612994995*^9, 3.474536164075149*^9, 3.474538463504343*^9, 
   3.600405361448472*^9},ExpressionUUID->"2d5bb626-b9fa-4fc1-93f1-\
fcbd76aea1c0"]
}, Open  ]],

Cell[TextData[StyleBox["The steady state equations are",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534604487265*^9, 
  3.47453460877466*^9}},ExpressionUUID->"20e88aac-91be-406f-be68-\
bc1a8e79d33c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"odes", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", " ", 
       RowBox[{"Length", "[", "odes", "]"}]}], "}"}]}], "]"}], "/.", 
   "rateqs"}], "/.", "parm"}]], "Input",
 CellChangeTimes->{{3.474534611642679*^9, 3.474534642616583*^9}, {
  3.474534673462545*^9, 
  3.4745346752766123`*^9}},ExpressionUUID->"c374ba38-8a8d-487d-801f-\
92eec36c11ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"50", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"x", "[", "t", "]"}], "500"]}], ")"}]}], 
      RowBox[{"6", "+", 
       RowBox[{"x", "[", "t", "]"}]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"x", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"y", "[", "t", "]"}], 
          RowBox[{"5", " ", 
           RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"x", "[", "t", "]"}], "5"], "+", 
       RowBox[{"10.`", " ", 
        RowBox[{"y", "[", "t", "]"}]}]}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"50", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["0.005000000000000001`", 
           RowBox[{"y", "[", "t", "]"}]]}], ")"}], " ", 
        RowBox[{"y", "[", "t", "]"}]}], 
       RowBox[{"1.1`", "\[VeryThinSpace]", "+", 
        RowBox[{"y", "[", "t", "]"}]}]]}], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"x", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"y", "[", "t", "]"}], 
          RowBox[{"5", " ", 
           RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"x", "[", "t", "]"}], "5"], "+", 
       RowBox[{"10.`", " ", 
        RowBox[{"y", "[", "t", "]"}]}]}]]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.4745346362476597`*^9, 3.474534643480834*^9}, 
   3.474536130006678*^9, 3.4745361641436787`*^9, 3.4745384695614767`*^9, 
   3.600405361579599*^9},ExpressionUUID->"d680aeb1-bcdf-447b-a174-\
bbee65ccca56"]
}, Open  ]],

Cell[TextData[StyleBox["FindRoot combines those two inputs to calculate the \
steady state",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534651575739*^9, 
  3.4745346640442963`*^9}},ExpressionUUID->"45e13400-51e5-49bc-9494-\
6a5e6cce83d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ss", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"odes", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", " ", 
          RowBox[{"Length", "[", "odes", "]"}]}], "}"}]}], "]"}], "/.", 
      "rateqs"}], "/.", "parm"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"vars", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"vars", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", "5", "]"}], "/.", "tsol"}], 
          ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "vars", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.474534665122904*^9, 
  3.474534691490851*^9}},ExpressionUUID->"c42a4c21-1c78-46a5-b0c7-\
ded4aa05d5a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "\[Rule]", "3.8699205577034164`"}], ",", 
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "\[Rule]", "0.12850635486274717`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.474534686432542*^9, 3.4745346920232573`*^9}, 
   3.474536130053687*^9, 3.474536164204544*^9, 3.474538470739834*^9, 
   3.600405361636242*^9},ExpressionUUID->"07464a1d-672f-4c7d-872c-\
88c5ddc635a8"]
}, Open  ]],

Cell[TextData[StyleBox["The fluxes at steady state are",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4745346942149143`*^9, 
  3.474534699194915*^9}},ExpressionUUID->"53280295-ddaa-4d55-8bf0-\
36e2c006152c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rateqs", "/.", "parm"}], "/.", "ss"}]], "Input",
 CellChangeTimes->{{3.474534702052706*^9, 
  3.474534708189342*^9}},ExpressionUUID->"00516f28-7d10-4602-b389-\
e3c22f07ab56"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"v1", "\[Rule]", "5.026687667258576`"}], ",", 
   RowBox[{"v2", "\[Rule]", "5.026687667258575`"}], ",", 
   RowBox[{"v3", "\[Rule]", "5.0266876672585745`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.474534708639379*^9, 3.474536130105598*^9, 
  3.474536164258613*^9, 3.474538472020177*^9, 
  3.600405361666987*^9},ExpressionUUID->"a0d77c5d-9867-4f1a-b546-\
cea5271ac8db"]
}, Open  ]],

Cell[TextData[StyleBox["Indeed they are all the same as expected and agree \
with the simulation",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534711205469*^9, 3.474534718474175*^9}, {
  3.474534807054922*^9, 
  3.4745348120305443`*^9}},ExpressionUUID->"7302871c-b2d4-4e13-a611-\
0e0a3367ddb9"],

Cell[TextData[StyleBox["System properties of the model such as a \
concentration or flux depends in a complicated nonlinear fashion on kinetic \
parameters to make those sensitivities explicit we will calculate sensitivity \
coefficients.  We change all the parameters by 1% and determine the % change \
in the concentrations and rates of the metabolic pathway at steady state.  \
This means we have to make the calculation of the time dependent solution \
with NDSolve and the steady state with FindRoot parameter dependent.",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474534881283897*^9, 
  3.474535024470508*^9}},ExpressionUUID->"3ba28dc4-e03c-4217-8fe3-\
fa199333d78c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"parmchange", "[", 
   RowBox[{"param_", ",", "newvalue_"}], "]"}], ":=", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{"parm", ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{"parm", ",", "param"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
     RowBox[{"param", "\[Rule]", "newvalue"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.474535032781283*^9, 
  3.474535120175839*^9}},ExpressionUUID->"91d7d5c6-f9fa-47da-94dd-\
af5d9d733188"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsolchange", "[", 
   RowBox[{"param_", ",", "newvalue_"}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"odes", "/.", "rateqs"}], "/.", 
       RowBox[{"parmchange", "[", 
        RowBox[{"param", ",", "newvalue"}], "]"}]}], ",", "init"}], "]"}], 
    ",", "vars", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.474535140756754*^9, 
  3.4745352043176403`*^9}},ExpressionUUID->"07a45516-6377-4533-8338-\
04a2bb476e33"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sschange", "[", 
   RowBox[{"param_", ",", "newvalue_"}], "]"}], ":=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"odes", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", " ", 
          RowBox[{"Length", "[", "odes", "]"}]}], "}"}]}], "]"}], "/.", 
      "rateqs"}], "/.", 
     RowBox[{"parmchange", "[", 
      RowBox[{"param", ",", "newvalue"}], "]"}]}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"vars", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"vars", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", "5", "]"}], "/.", 
           RowBox[{"tsolchange", "[", 
            RowBox[{"param", ",", "newvalue"}], "]"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "vars", "]"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.474535208392577*^9, 
  3.4745352758608723`*^9}},ExpressionUUID->"c296f58a-c9d0-45f9-b708-\
b8f33b5da697"],

Cell[TextData[StyleBox["Now we can for instance determine the dependency of \
the steady state flux through the metabolic pathway as function of the \
maximal rate of enzyme 1. ",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474535483264039*^9, 
  3.474535515730624*^9}},ExpressionUUID->"09e174d1-b7d3-4da0-bacd-\
c152006ed6e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"v1", "/.", "rateqs"}], "/.", 
       RowBox[{"parmchange", "[", 
        RowBox[{"V1", ",", "i"}], "]"}]}], "/.", 
      RowBox[{"sschange", "[", 
       RowBox[{"V1", ",", "i"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "100", ",", "2.5"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "20"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], ",", " ", 
      
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<maximal rate first enzyme, V1\>\"", ",", 
      "\"\<steady-state rate first enzyme\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.474535297188015*^9, 
  3.474535457359786*^9}},ExpressionUUID->"d319638c-899e-4dc2-ba69-\
3e4cd7e240a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.7982681462552436`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.5`", ",", "2.445058453127863`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.`", ",", "3.6554299614826626`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.5`", ",", "4.57254461086868`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11.`", ",", "5.299028957023237`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13.5`", ",", "5.896220724532785`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16.`", ",", "6.401289016168142`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18.5`", ",", "6.8378577471389015`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"21.`", ",", "7.2216854141696`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23.5`", ",", "7.563738231855521`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"26.`", ",", "7.8719255596322775`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28.5`", ",", "8.152126381989063`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", "8.408823142364431`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"33.5`", ",", "8.645508373060276`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"36.`", ",", "8.864954456899241`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"38.5`", ",", "9.06939791771648`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"41.`", ",", "9.260668604094564`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"43.5`", ",", "9.440282323346066`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"46.`", ",", "9.609508616237536`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48.5`", ",", "9.769421240140838`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"51.`", ",", "9.920936380429662`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"53.5`", ",", "10.064841993818968`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"56.`", ",", "10.201820637785687`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"58.5`", ",", "10.332467443857052`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"61.`", ",", "10.457304421462268`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"63.5`", ",", "10.576791954628764`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"66.`", ",", "10.69133812673072`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"68.5`", ",", "10.801306347161363`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"71.`", ",", "10.907021637579419`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"73.5`", ",", "11.008775850584543`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"76.`", ",", "11.106832031073843`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"78.5`", ",", "11.201428083803613`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"81.`", ",", "11.292779875443312`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"83.5`", ",", "11.38108387258168`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"86.`", ",", "11.466519396538121`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"88.5`", ",", "11.54925055986979`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"91.`", ",", "11.629427937003097`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"93.5`", ",", "11.707190011616449`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"96.`", ",", "11.782664435638203`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"98.5`", ",", "11.8559691285346`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4745353437556953`*^9, 3.4745353605744753`*^9}, {
   3.474535416832728*^9, 3.4745354583981037`*^9}, 3.47453613100132*^9, 
   3.474536165244691*^9, 3.474538477526167*^9, 
   3.600405362253984*^9},ExpressionUUID->"6e877e2b-4ac1-46bc-ba60-\
1dd1aaf3272b"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7JdHbV6c2f3SHsLncVj/If1cVT+zA4Qv4bBV
3FsgyI4Xyld0SN2Vo+TpJQTlqznIPZ691MRIFMrXdmgp2/5o11RxKN/AYfk+
pqbXsyQh/AYjhy1LZyV+j5SGyps6OOb7NzA+loHKmzvI+oTOcHGUg8pbOais
PsN7q0YeKm/j8IEhvOmxrwJU3t7BenaIS+BFKP+Ag4Oo7nmhBi9FqLyTw4lL
jf63d0H5Ds4OOYzb5DuUlaDmuThYxnyOKmuF8g+4OpT3ua/PeQjlM7g7rNyb
1SxooQzV7+EQ27huysdOKL/B02Gbh/rPlutQ/gEvB9cdrj+MFFWg+n0cBJ7e
5QhNh/IdfB2mbbbRsVwF5Tf4OXj8kzmn/ArKP+Dv8Kk42y1QXRUqH+AwZ5Km
0PdEKF8h0MHZNeyyyywo/0CgA0PYHeXUC1B+QpDDyqZ1LnUsalD7gx1sHOU3
bDKD8hcEO+Tc/TBFMR3KdwhxKHuZbfd8KpT/IMThXdfjHNnDUH5DqEOWZtzC
2++gfIUwhwXP+uPMJdWh9oc5vLN+meDiBOUnhDusfKZ+XiQLymeIcHgyd2rK
zglQ/oIIB61Hr6Y6blN3AAA9LqjW
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Gill Sans Light", FontSize -> 16},
  Frame->True,
  FrameLabel->{{
     FormBox["\"steady-state rate first enzyme\"", TraditionalForm], None}, {
     FormBox["\"maximal rate first enzyme, V1\"", TraditionalForm], None}},
  Method->{},
  PlotRange->{{0, 100}, {0, 20}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4745353437556953`*^9, 3.4745353605744753`*^9}, {
   3.474535416832728*^9, 3.4745354583981037`*^9}, 3.47453613100132*^9, 
   3.474536165244691*^9, 3.474538477526167*^9, 
   3.600405362617951*^9},ExpressionUUID->"819687f4-97ff-4e49-b267-\
ba85538a1f4f"]
}, Open  ]],

Cell[TextData[StyleBox["Determining the sensitvity coefficients \n\nExample \
calculation",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474535576279892*^9, 
  3.474535592375675*^9}},ExpressionUUID->"e98a6ee1-d669-4d69-bd6a-\
116abe5662a3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sschange", "[", 
   RowBox[{"V1", ",", 
    RowBox[{
     RowBox[{"1.01", "*", "V1"}], "/.", "parm"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"new", " ", "steady", " ", "state"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sschange", "[", 
   RowBox[{"V1", ",", 
    RowBox[{"V1", "/.", "parm"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"reference", " ", "steady", " ", "state"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "/.", "%%"}], ")"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "/.", "%"}], ")"}]}], 
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "/.", "%"}]], 
  RowBox[{"(*", " ", 
   RowBox[{"fractional", " ", "change", " ", "in", " ", 
    RowBox[{"x", "[", "t", "]"}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.4745355449557133`*^9, 3.474535564620553*^9}, {
  3.4745355958004007`*^9, 
  3.4745356830406733`*^9}},ExpressionUUID->"297e4b2d-f45a-4ae0-8adf-\
8c0dadfeb016"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "\[Rule]", "3.912084402683036`"}], ",", 
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "\[Rule]", "0.12927828004944114`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.4745355553938847`*^9, {3.47453561471945*^9, 3.474535683844034*^9}, 
   3.474536131322233*^9, 3.474536165579158*^9, 3.474538479321686*^9, 
   3.600405362734311*^9},ExpressionUUID->"0a828c9f-ca8f-49eb-aa8b-\
89e66df544b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t", "]"}], "\[Rule]", "3.8699205577034164`"}], ",", 
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "\[Rule]", "0.12850635486274717`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.4745355553938847`*^9, {3.47453561471945*^9, 3.474535683844034*^9}, 
   3.474536131322233*^9, 3.474536165579158*^9, 3.474538479321686*^9, 
   3.600405362773582*^9},ExpressionUUID->"d7a622d2-49a0-4993-8b3f-\
0c1662237a0e"],

Cell[BoxData["0.010895274037522223`"], "Output",
 CellChangeTimes->{
  3.4745355553938847`*^9, {3.47453561471945*^9, 3.474535683844034*^9}, 
   3.474536131322233*^9, 3.474536165579158*^9, 3.474538479321686*^9, 
   3.6004053627749033`*^9},ExpressionUUID->"cd22476b-ed6d-4827-b0db-\
2ec5b03de394"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"onepercup", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"parm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], "/.", 
            RowBox[{"sschange", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"parm", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"1.01", "*", 
               RowBox[{
                RowBox[{"parm", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], "/.", 
            RowBox[{"sschange", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"parm", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"parm", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "/.", 
          RowBox[{"sschange", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"parm", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"parm", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}]}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "parm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onepercdown", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"parm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], "/.", 
            RowBox[{"sschange", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"parm", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"0.99", "*", 
               RowBox[{
                RowBox[{"parm", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], "/.", 
            RowBox[{"sschange", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"parm", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{
               RowBox[{"parm", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "/.", 
          RowBox[{"sschange", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"parm", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"parm", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}]}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "parm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.474535697184206*^9, 3.474535837369667*^9}, {
  3.474536410634317*^9, 
  3.47453641179221*^9}},ExpressionUUID->"9c543bb3-b7a7-4f2f-a2e8-\
e15c6a33e446"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TableForm", "[", "onepercup", "]"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "onepercdown", "]"}]}], "Input",
 CellChangeTimes->{{3.474536414398149*^9, 
  3.474536430303377*^9}},ExpressionUUID->"3ad076a0-af95-4243-90b8-\
7a7cebf03f01"],

Cell[BoxData[
 TagBox[GridBox[{
    {"V1", "0.010895274037522223`"},
    {"K1s", 
     RowBox[{"-", "0.005340649977644886`"}]},
    {"Keq1", "0.0000841793220757965`"},
    {"K1x", "0.004258033873214958`"},
    {"V2", 
     RowBox[{"-", "0.00742083374233411`"}]},
    {"K2x", "0.005576450589904226`"},
    {"Keq2", 
     RowBox[{"-", "0.000049550812575911`"}]},
    {"K2y", 
     RowBox[{"-", "0.003119953064261485`"}]},
    {"V3", 
     RowBox[{"-", "0.003384257922534688`"}]},
    {"K3y", "0.0030500438493368713`"},
    {"Keq3", 
     RowBox[{"-", "0.00013682693429160108`"}]},
    {"K3p", 
     RowBox[{"-", "0.00027515556465229114`"}]},
    {"s", "0.005446448163326269`"},
    {"p", "0.0004159494914974585`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.474536425738595*^9, 3.474536431244009*^9}, 
   3.474538482204608*^9, 
   3.600405364979653*^9},ExpressionUUID->"c6f7321f-da6c-411f-a6c0-\
174eaef62781"],

Cell[BoxData[
 TagBox[GridBox[{
    {"V1", 
     RowBox[{"-", "0.010902571187831632`"}]},
    {"K1s", "0.005415229430947011`"},
    {"Keq1", 
     RowBox[{"-", "0.00008586564684433885`"}]},
    {"K1x", 
     RowBox[{"-", "0.004288910246105072`"}]},
    {"V2", "0.00755134808191549`"},
    {"K2x", 
     RowBox[{"-", "0.005606791772810694`"}]},
    {"Keq2", "0.000050550461162877744`"},
    {"K2y", "0.0031695539206597406`"},
    {"V3", "0.003443199296781864`"},
    {"K3y", 
     RowBox[{"-", "0.0030628090100524143`"}]},
    {"Keq3", "0.00013958018285390372`"},
    {"K3p", "0.0002806076917728879`"},
    {"s", 
     RowBox[{"-", "0.005479041148329885`"}]},
    {"p", 
     RowBox[{"-", "0.00041614003498117395`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.474536425738595*^9, 3.474536431244009*^9}, 
   3.474538482204608*^9, 
   3.600405364983376*^9},ExpressionUUID->"f2ac731a-8e00-4237-a85c-\
6e52d5bd620d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BarChart", "[", 
   RowBox[{
    RowBox[{"onepercup", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"ChartLabels", "\[Rule]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ToString", "[", 
        RowBox[{
         RowBox[{"parm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "parm", "]"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"BarOrigin", "\[Rule]", "Left"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], ",", " ", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"onepercdown", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{
        RowBox[{"parm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "parm", "]"}]}], "}"}]}], "]"}]}], ",", 
   RowBox[{"BarOrigin", "\[Rule]", "Left"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], ",", " ", 
      
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.474535847639597*^9, 3.474535909638234*^9}, {
  3.474535943300557*^9, 3.474535976989163*^9}, {3.474536056427162*^9, 
  3.4745360752953157`*^9}, {3.474536281931779*^9, 3.474536400662443*^9}, {
  3.474536441757617*^9, 3.474536444238508*^9}, {3.474536892594624*^9, 
  3.474536895097192*^9}},ExpressionUUID->"8fe88e7a-52bb-4cdd-a503-\
2895c0e76816"],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{{0., 0.44545454545454544`}}]}, {{}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[{Opacity[0.7], Thickness[Small]}], 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 0.5454545454545454}, {0.010895274037522223`, 
            1.4545454545454546`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 351.59000000000003`}, {
           79.28120213465775, 93.56484400704994}}],
         StatusArea[#, 0.010895274037522223`]& ,
         TagBoxNote->"0.010895274037522223"],
        StyleBox["0.010895274037522223`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.010895274037522223`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 1.5454545454545454`}, {-0.005340649977644886, 
            2.4545454545454546`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{46.44217675070924, 147.1531280280112}, {
           64.11919607502631, 78.40283794741852}}],
         StatusArea[#, -0.005340649977644886]& ,
         TagBoxNote->"-0.005340649977644886"],
        StyleBox[
         RowBox[{"-", "0.005340649977644886`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.005340649977644886, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 2.5454545454545454`}, {0.0000841793220757965, 
            3.4545454545454546`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 148.73265298815733`}, {
           48.95719001539489, 63.240831887787095`}}],
         StatusArea[#, 0.0000841793220757965]& ,
         TagBoxNote->"0.0000841793220757965"],
        StyleBox["0.0000841793220757965`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.0000841793220757965, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 3.5454545454545454`}, {0.004258033873214958, 
            4.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 227.0500744281593}, {
           33.79518395576348, 48.07882582815567}}],
         StatusArea[#, 0.004258033873214958]& ,
         TagBoxNote->"0.004258033873214958"],
        StyleBox["0.004258033873214958`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.004258033873214958, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 4.545454545454545}, {-0.00742083374233411, 
            5.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{7.410000000000025, 147.1531280280112}, {
           18.63317789613204, 32.91681976852425}}],
         StatusArea[#, -0.00742083374233411]& ,
         TagBoxNote->"-0.00742083374233411"],
        StyleBox[
         RowBox[{"-", "0.00742083374233411`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.00742083374233411, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 5.545454545454545}, {0.005576450589904226, 
            6.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 251.78859762521603`}, {
           3.4711718365006163`, 17.754813708892826`}}],
         StatusArea[#, 0.005576450589904226]& ,
         TagBoxNote->"0.005576450589904226"],
        StyleBox["0.005576450589904226`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.005576450589904226, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 6.545454545454545}, {-0.000049550812575911, 
            7.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{145.72336590437826`, 
           147.1531280280112}, {-11.690834223130807`, 2.5928076492614025`}}],
         StatusArea[#, -0.000049550812575911]& ,
         TagBoxNote->"-0.000049550812575911"],
        StyleBox[
         RowBox[{"-", "0.000049550812575911`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.000049550812575911, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 7.545454545454545}, {-0.003119953064261485, 
            8.454545454545453}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{88.1109157843902, 
           147.1531280280112}, {-26.852840282762216`, -12.56919841037002}}],
         StatusArea[#, -0.003119953064261485]& ,
         TagBoxNote->"-0.003119953064261485"],
        StyleBox[
         RowBox[{"-", "0.003119953064261485`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.003119953064261485, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 8.545454545454545}, {-0.003384257922534688, 
            9.454545454545453}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{83.15154915567697, 
           147.1531280280112}, {-42.01484634239365, -27.731204470001458`}}],
         StatusArea[#, -0.003384257922534688]& ,
         TagBoxNote->"-0.003384257922534688"],
        StyleBox[
         RowBox[{"-", "0.003384257922534688`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.003384257922534688, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 9.545454545454545}, {0.0030500438493368713`, 
            10.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 
           204.38357691699005`}, {-57.17685240202506, -42.89321052963287}}],
         StatusArea[#, 0.0030500438493368713`]& ,
         TagBoxNote->"0.0030500438493368713"],
        StyleBox["0.0030500438493368713`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.0030500438493368713`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 10.545454545454545`}, {-0.00013682693429160108`, 
            11.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{144.08573317848678`, 
           147.1531280280112}, {-72.3388584616565, -58.055216589264305`}}],
         StatusArea[#, -0.00013682693429160108`]& ,
         TagBoxNote->"-0.00013682693429160108"],
        StyleBox[
         RowBox[{"-", "0.00013682693429160108`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.00013682693429160108`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 11.545454545454545`}, {-0.00027515556465229114`, 
            12.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{141.49016078648293`, 
           147.1531280280112}, {-87.50086452128791, -73.21722264889571}}],
         StatusArea[#, -0.00027515556465229114`]& ,
         TagBoxNote->"-0.00027515556465229114"],
        StyleBox[
         RowBox[{"-", "0.00027515556465229114`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.00027515556465229114`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 12.545454545454545`}, {0.005446448163326269, 
            13.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 
           249.34925655432272`}, {-102.66287058091935`, -88.37922870852715}}],
         
         StatusArea[#, 0.005446448163326269]& ,
         TagBoxNote->"0.005446448163326269"],
        StyleBox["0.005446448163326269`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.005446448163326269, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 13.545454545454545`}, {0.0004159494914974585, 
            14.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{146.6531280280112, 
           154.95792602090484`}, {-117.82487664055076`, \
-103.54123476815856`}}],
         StatusArea[#, 0.0004159494914974585]& ,
         TagBoxNote->"0.0004159494914974585"],
        StyleBox["0.0004159494914974585`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.0004159494914974585, {
          GrayLevel[0]}], "Tooltip"]& ]}}, {}, {}}, {}, {}, GraphicsGroupBox[
    {GrayLevel[0], 
     StyleBox[
      StyleBox[{
        {Thickness[Tiny], 
         LineBox[{{0., 0.44545454545454544`}, {0., 
          14.454545454545451`}}], {}}, {
         {Thickness[Tiny], 
          LineBox[{{0., 0.5454545454545454}, 
            Offset[{-6., 0.}, {0., 0.5454545454545454}]}], 
          LineBox[{{0., 14.454545454545451`}, 
            Offset[{-6., 0.}, {0., 
             14.454545454545451`}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {
            LineBox[{{0., 1.4545454545454546`}, 
              Offset[{-4., 0.}, {0., 1.4545454545454546`}]}], 
            LineBox[{{0., 1.5454545454545454`}, 
              Offset[{-4., 0.}, {0., 1.5454545454545454`}]}], 
            LineBox[{{0., 2.4545454545454546`}, 
              Offset[{-4., 0.}, {0., 2.4545454545454546`}]}], 
            LineBox[{{0., 2.5454545454545454`}, 
              Offset[{-4., 0.}, {0., 2.5454545454545454`}]}], 
            LineBox[{{0., 3.4545454545454546`}, 
              Offset[{-4., 0.}, {0., 3.4545454545454546`}]}], 
            LineBox[{{0., 3.5454545454545454`}, 
              Offset[{-4., 0.}, {0., 3.5454545454545454`}]}], 
            LineBox[{{0., 4.454545454545454}, 
              Offset[{-4., 0.}, {0., 4.454545454545454}]}], 
            LineBox[{{0., 4.545454545454545}, 
              Offset[{-4., 0.}, {0., 4.545454545454545}]}], 
            LineBox[{{0., 5.454545454545453}, 
              Offset[{-4., 0.}, {0., 5.454545454545453}]}], 
            LineBox[{{0., 5.545454545454545}, 
              Offset[{-4., 0.}, {0., 5.545454545454545}]}], 
            LineBox[{{0., 6.454545454545453}, 
              Offset[{-4., 0.}, {0., 6.454545454545453}]}], 
            LineBox[{{0., 6.545454545454545}, 
              Offset[{-4., 0.}, {0., 6.545454545454545}]}], 
            LineBox[{{0., 7.454545454545453}, 
              Offset[{-4., 0.}, {0., 7.454545454545453}]}], 
            LineBox[{{0., 7.545454545454545}, 
              Offset[{-4., 0.}, {0., 7.545454545454545}]}], 
            LineBox[{{0., 8.454545454545453}, 
              Offset[{-4., 0.}, {0., 8.454545454545453}]}], 
            LineBox[{{0., 8.545454545454543}, 
              Offset[{-4., 0.}, {0., 8.545454545454543}]}], 
            LineBox[{{0., 9.454545454545451}, 
              Offset[{-4., 0.}, {0., 9.454545454545451}]}], 
            LineBox[{{0., 9.545454545454543}, 
              Offset[{-4., 0.}, {0., 9.545454545454543}]}], 
            LineBox[{{0., 10.454545454545451`}, 
              Offset[{-4., 0.}, {0., 10.454545454545451`}]}], 
            LineBox[{{0., 10.545454545454543`}, 
              Offset[{-4., 0.}, {0., 10.545454545454543`}]}], 
            LineBox[{{0., 11.454545454545451`}, 
              Offset[{-4., 0.}, {0., 11.454545454545451`}]}], 
            LineBox[{{0., 11.545454545454543`}, 
              Offset[{-4., 0.}, {0., 11.545454545454543`}]}], 
            LineBox[{{0., 12.454545454545451`}, 
              Offset[{-4., 0.}, {0., 12.454545454545451`}]}], 
            LineBox[{{0., 12.545454545454543`}, 
              Offset[{-4., 0.}, {0., 12.545454545454543`}]}], 
            LineBox[{{0., 13.454545454545451`}, 
              Offset[{-4., 0.}, {0., 13.454545454545451`}]}], 
            LineBox[{{0., 13.545454545454543`}, 
              Offset[{-4., 0.}, {0., 13.545454545454543`}]}]}, {}}}, 
         {Thickness[Tiny], 
          InsetBox["\<\"V1\"\>", Offset[{-2., 0.}, {0., 1.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"K1s\"\>", Offset[{-2., 0.}, {0., 2.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"Keq1\"\>", Offset[{-2., 0.}, {0., 3.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"K1x\"\>", 
           Offset[{-2., 0.}, {0., 3.9999999999999996}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"V2\"\>", Offset[{-2., 0.}, {0., 5.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"K2x\"\>", 
           Offset[{-2., 0.}, {0., 5.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"Keq2\"\>", 
           Offset[{-2., 0.}, {0., 6.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"K2y\"\>", 
           Offset[{-2., 0.}, {0., 7.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"V3\"\>", 
           Offset[{-2., 0.}, {0., 8.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"K3y\"\>", 
           Offset[{-2., 0.}, {0., 9.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"Keq3\"\>", 
           Offset[{-2., 0.}, {0., 10.999999999999998}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"K3p\"\>", 
           Offset[{-2., 0.}, {0., 11.999999999999998}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"s\"\>", 
           Offset[{-2., 0.}, {0., 12.999999999999998}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"p\"\>", 
           Offset[{-2., 0.}, {0., 13.999999999999998}], {1, 0}, Automatic, {1,
            0}]}}}, "GraphicsAxes",
       StripOnInput->False,
       Antialiasing->False],
      Antialiasing->False]}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.44545454545454544`},
  BaseStyle->{FontFamily -> "Gill Sans Light", FontSize -> 16},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{3.47453694814091*^9, 3.4745384836023293`*^9, 
  3.600405365551013*^9},ExpressionUUID->"aa4b65dd-68a9-419d-baa3-\
1ab6a7d99922"],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{{0., 0.44545454545454544`}}]}, {{}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[{Opacity[0.7], Thickness[Small]}], 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 0.5454545454545454}, {-0.010902571187831632`, 
            1.4545454545454546`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{10.068153090196319`, 212.07583019164056`}, {
           78.75429303727655, 92.93350260366813}}],
         StatusArea[#, -0.010902571187831632`]& ,
         TagBoxNote->"-0.010902571187831632"],
        StyleBox[
         RowBox[{"-", "0.010902571187831632`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.010902571187831632`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 1.5454545454545454`}, {0.005415229430947011, 
            2.4545454545454546`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 312.16325771693926`}, {
           63.70716251424581, 77.88637208063739}}],
         StatusArea[#, 0.005415229430947011]& ,
         TagBoxNote->"0.005415229430947011"],
        StyleBox["0.005415229430947011`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.005415229430947011, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 2.5454545454545454`}, {-0.00008586564684433885, 
            3.4545454545454546`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{209.98881124534586`, 212.07583019164056`}, {
           48.66003199121507, 62.839241557606655`}}],
         StatusArea[#, -0.00008586564684433885]& ,
         TagBoxNote->"-0.00008586564684433885"],
        StyleBox[
         RowBox[{"-", "0.00008586564684433885`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.00008586564684433885, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 3.5454545454545454`}, {-0.004288910246105072, 
            4.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{132.3056905062602, 212.07583019164056`}, {
           33.61290146818433, 47.79211103457591}}],
         StatusArea[#, -0.004288910246105072]& ,
         TagBoxNote->"-0.004288910246105072"],
        StyleBox[
         RowBox[{"-", "0.004288910246105072`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.004288910246105072, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 4.545454545454545}, {0.00755134808191549, 
            5.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 351.6442480222489}, {
           18.565770945153602`, 32.74498051154518}}],
         StatusArea[#, 0.00755134808191549]& ,
         TagBoxNote->"0.00755134808191549"],
        StyleBox["0.00755134808191549`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.00755134808191549, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 5.545454545454545}, {-0.005606791772810694, 
            6.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{107.94783577950088`, 212.07583019164056`}, {
           3.518640422122857, 17.697849988514434`}}],
         StatusArea[#, -0.005606791772810694]& ,
         TagBoxNote->"-0.005606791772810694"],
        StyleBox[
         RowBox[{"-", "0.005606791772810694`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.005606791772810694, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 6.545454545454545}, {0.000050550461162877744`, 
            7.454545454545454}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 
           213.01013328674048`}, {-11.528490100907888`, 2.6507194654837036`}}],
         StatusArea[#, 0.000050550461162877744`]& ,
         TagBoxNote->"0.000050550461162877744"],
        StyleBox["0.000050550461162877744`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.000050550461162877744`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 7.545454545454545}, {0.0031695539206597406`, 
            8.454545454545453}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 
           270.65737366395115`}, {-26.575620623938605`, \
-12.396411057547041`}}],
         StatusArea[#, 0.0031695539206597406`]& ,
         TagBoxNote->"0.0031695539206597406"],
        StyleBox["0.0031695539206597406`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.0031695539206597406`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 8.545454545454545}, {0.003443199296781864, 
            9.454545454545453}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 
           275.71504704593866`}, {-41.622751146969335`, \
-27.443541580577772`}}],
         StatusArea[#, 0.003443199296781864]& ,
         TagBoxNote->"0.003443199296781864"],
        StyleBox["0.003443199296781864`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.003443199296781864, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 9.545454545454545}, {-0.0030628090100524143`, 
            10.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{154.96720839150314`, 
           212.07583019164056`}, {-56.66988167000008, -42.49067210360852}}],
         StatusArea[#, -0.0030628090100524143`]& ,
         TagBoxNote->"-0.0030628090100524143"],
        StyleBox[
         RowBox[{"-", "0.0030628090100524143`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.0030628090100524143`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 10.545454545454545`}, {0.00013958018285390372`, 
            11.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 
           214.65563250906794`}, {-71.71701219303083, -57.53780262663926}}],
         StatusArea[#, 0.00013958018285390372`]& ,
         TagBoxNote->"0.00013958018285390372"],
        StyleBox["0.00013958018285390372`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.00013958018285390372`, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 11.545454545454545`}, {0.0002806076917728879, 
            12.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{211.57583019164056`, 
           217.26218515064897`}, {-86.76414271606157, -72.58493314967001}}],
         StatusArea[#, 0.0002806076917728879]& ,
         TagBoxNote->"0.0002806076917728879"],
        StyleBox["0.0002806076917728879`", {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.0002806076917728879, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 12.545454545454545`}, {-0.005479041148329885, 
            13.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{110.30899730221748`, 
           212.07583019164056`}, {-101.81127323909232`, -87.63206367270072}}],
         
         StatusArea[#, -0.005479041148329885]& ,
         TagBoxNote->"-0.005479041148329885"],
        StyleBox[
         RowBox[{"-", "0.005479041148329885`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.005479041148329885, {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[{Opacity[0.7], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 13.545454545454545`}, {-0.00041614003498117395`, 
            14.454545454545453`}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{203.88448744750318`, 
           212.07583019164056`}, {-116.85840376212306`, \
-102.67919419573147`}}],
         StatusArea[#, -0.00041614003498117395`]& ,
         TagBoxNote->"-0.00041614003498117395"],
        StyleBox[
         RowBox[{"-", "0.00041614003498117395`"}], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[-0.00041614003498117395`, {
          GrayLevel[0]}], "Tooltip"]& ]}}, {}, {}}, {}, {}, GraphicsGroupBox[
    {GrayLevel[0], 
     StyleBox[
      StyleBox[{
        {Thickness[Tiny], 
         LineBox[{{0., 0.44545454545454544`}, {0., 
          14.454545454545451`}}], {}}, {
         {Thickness[Tiny], 
          LineBox[{{0., 0.5454545454545454}, 
            Offset[{-6., 0.}, {0., 0.5454545454545454}]}], 
          LineBox[{{0., 14.454545454545451`}, 
            Offset[{-6., 0.}, {0., 
             14.454545454545451`}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {
            LineBox[{{0., 1.4545454545454546`}, 
              Offset[{-4., 0.}, {0., 1.4545454545454546`}]}], 
            LineBox[{{0., 1.5454545454545454`}, 
              Offset[{-4., 0.}, {0., 1.5454545454545454`}]}], 
            LineBox[{{0., 2.4545454545454546`}, 
              Offset[{-4., 0.}, {0., 2.4545454545454546`}]}], 
            LineBox[{{0., 2.5454545454545454`}, 
              Offset[{-4., 0.}, {0., 2.5454545454545454`}]}], 
            LineBox[{{0., 3.4545454545454546`}, 
              Offset[{-4., 0.}, {0., 3.4545454545454546`}]}], 
            LineBox[{{0., 3.5454545454545454`}, 
              Offset[{-4., 0.}, {0., 3.5454545454545454`}]}], 
            LineBox[{{0., 4.454545454545454}, 
              Offset[{-4., 0.}, {0., 4.454545454545454}]}], 
            LineBox[{{0., 4.545454545454545}, 
              Offset[{-4., 0.}, {0., 4.545454545454545}]}], 
            LineBox[{{0., 5.454545454545453}, 
              Offset[{-4., 0.}, {0., 5.454545454545453}]}], 
            LineBox[{{0., 5.545454545454545}, 
              Offset[{-4., 0.}, {0., 5.545454545454545}]}], 
            LineBox[{{0., 6.454545454545453}, 
              Offset[{-4., 0.}, {0., 6.454545454545453}]}], 
            LineBox[{{0., 6.545454545454545}, 
              Offset[{-4., 0.}, {0., 6.545454545454545}]}], 
            LineBox[{{0., 7.454545454545453}, 
              Offset[{-4., 0.}, {0., 7.454545454545453}]}], 
            LineBox[{{0., 7.545454545454545}, 
              Offset[{-4., 0.}, {0., 7.545454545454545}]}], 
            LineBox[{{0., 8.454545454545453}, 
              Offset[{-4., 0.}, {0., 8.454545454545453}]}], 
            LineBox[{{0., 8.545454545454543}, 
              Offset[{-4., 0.}, {0., 8.545454545454543}]}], 
            LineBox[{{0., 9.454545454545451}, 
              Offset[{-4., 0.}, {0., 9.454545454545451}]}], 
            LineBox[{{0., 9.545454545454543}, 
              Offset[{-4., 0.}, {0., 9.545454545454543}]}], 
            LineBox[{{0., 10.454545454545451`}, 
              Offset[{-4., 0.}, {0., 10.454545454545451`}]}], 
            LineBox[{{0., 10.545454545454543`}, 
              Offset[{-4., 0.}, {0., 10.545454545454543`}]}], 
            LineBox[{{0., 11.454545454545451`}, 
              Offset[{-4., 0.}, {0., 11.454545454545451`}]}], 
            LineBox[{{0., 11.545454545454543`}, 
              Offset[{-4., 0.}, {0., 11.545454545454543`}]}], 
            LineBox[{{0., 12.454545454545451`}, 
              Offset[{-4., 0.}, {0., 12.454545454545451`}]}], 
            LineBox[{{0., 12.545454545454543`}, 
              Offset[{-4., 0.}, {0., 12.545454545454543`}]}], 
            LineBox[{{0., 13.454545454545451`}, 
              Offset[{-4., 0.}, {0., 13.454545454545451`}]}], 
            LineBox[{{0., 13.545454545454543`}, 
              Offset[{-4., 0.}, {0., 13.545454545454543`}]}]}, {}}}, 
         {Thickness[Tiny], 
          InsetBox["\<\"V1\"\>", Offset[{-2., 0.}, {0., 1.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"K1s\"\>", Offset[{-2., 0.}, {0., 2.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"Keq1\"\>", Offset[{-2., 0.}, {0., 3.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"K1x\"\>", 
           Offset[{-2., 0.}, {0., 3.9999999999999996}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"V2\"\>", Offset[{-2., 0.}, {0., 5.}], {1, 0}, 
           Automatic, {1, 0}], 
          InsetBox["\<\"K2x\"\>", 
           Offset[{-2., 0.}, {0., 5.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"Keq2\"\>", 
           Offset[{-2., 0.}, {0., 6.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"K2y\"\>", 
           Offset[{-2., 0.}, {0., 7.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"V3\"\>", 
           Offset[{-2., 0.}, {0., 8.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"K3y\"\>", 
           Offset[{-2., 0.}, {0., 9.999999999999998}], {1, 0}, Automatic, {1, 
           0}], InsetBox["\<\"Keq3\"\>", Offset[{-2., 0.}, 
           {0., 10.999999999999998}], {1, 0}, Automatic, {1, 0}], 
          InsetBox["\<\"K3p\"\>", 
           Offset[{-2., 0.}, {0., 11.999999999999998}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"s\"\>", 
           Offset[{-2., 0.}, {0., 12.999999999999998}], {1, 0}, Automatic, {1,
            0}], InsetBox["\<\"p\"\>", 
           Offset[{-2., 0.}, {0., 13.999999999999998}], {1, 0}, Automatic, {1,
            0}]}}}, "GraphicsAxes",
       StripOnInput->False,
       Antialiasing->False],
      Antialiasing->False]}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.44545454545454544`},
  BaseStyle->{FontFamily -> "Gill Sans Light", FontSize -> 16},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{3.47453694814091*^9, 3.4745384836023293`*^9, 
  3.60040536562953*^9},ExpressionUUID->"72f76783-f46d-4a47-80fa-75807def5df6"]
}, Open  ]],

Cell[TextData[StyleBox["So clearly some parameters have a larger effect on \
the steady state concentration of metabolite concentration X than others.",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474536903847825*^9, 
  3.474536941193241*^9}},ExpressionUUID->"80caef5f-f2a2-402b-8e17-\
5671933e82cd"],

Cell[TextData[StyleBox["We can also use manipulate to study the model \
dynamics.  If you want be able to vary all parameters with sliders then you \
can do it as follows",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.474537585791844*^9, 
  3.474537637037632*^9}},ExpressionUUID->"e2c5a239-3b6b-4294-93ae-\
a18b59788d26"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsolmanipulate", "[", 
   RowBox[{
   "s_", ",", "V1_", ",", "K1s_", ",", "K1x_", ",", "Keq1_", ",", "V2_", ",", 
    "K2x_", ",", "Keq2_", ",", "K2y_", ",", "V3_", ",", "K3y_", ",", "Keq3_", 
    ",", "K3p_", ",", "x0_", ",", "y0_", ",", "p_"}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        FractionBox[
         RowBox[{"s", " ", "V1", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"x", "[", "t", "]"}], 
             RowBox[{"Keq1", " ", "s"}]]}], ")"}]}], 
         RowBox[{"K1s", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox["s", "K1s"], "+", 
            FractionBox[
             RowBox[{"x", "[", "t", "]"}], "K1x"]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"V2", " ", 
          RowBox[{"x", "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"y", "[", "t", "]"}], 
             RowBox[{"Keq2", " ", 
              RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
         RowBox[{"K2x", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"x", "[", "t", "]"}], "K2x"], "+", 
            FractionBox[
             RowBox[{"y", "[", "t", "]"}], "K2y"]}], ")"}]}]]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"V3", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["p", 
              RowBox[{"Keq3", " ", 
               RowBox[{"y", "[", "t", "]"}]}]]}], ")"}], " ", 
           RowBox[{"y", "[", "t", "]"}]}], 
          RowBox[{"K3y", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox["p", "K3p"], "+", 
             FractionBox[
              RowBox[{"y", "[", "t", "]"}], "K3y"]}], ")"}]}]]}], "+", 
        FractionBox[
         RowBox[{"V2", " ", 
          RowBox[{"x", "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"y", "[", "t", "]"}], 
             RowBox[{"Keq2", " ", 
              RowBox[{"x", "[", "t", "]"}]}]]}], ")"}]}], 
         RowBox[{"K2x", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"x", "[", "t", "]"}], "K2x"], "+", 
            FractionBox[
             RowBox[{"y", "[", "t", "]"}], "K2y"]}], ")"}]}]]}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "\[Equal]", "x0"}], ",", 
      RowBox[{
       RowBox[{"y", "[", "0", "]"}], "\[Equal]", "y0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "20"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4745376384774227`*^9, 3.474537814592917*^9}, {
  3.474538203358954*^9, 
  3.474538204524219*^9}},ExpressionUUID->"7023f64b-f1f4-403b-8cbb-\
9f9eb9684d46"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "sol", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sol", "=", 
       RowBox[{"tsolmanipulate", "[", 
        RowBox[{
        "s", ",", "V1", ",", "K1s", ",", "K1x", ",", "Keq1", ",", "V2", ",", 
         "K2x", ",", "Keq2", ",", "K2y", ",", "V3", ",", "K3y", ",", "Keq3", 
         ",", "K3p", ",", "x0", ",", "y0", ",", "p"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], ",", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "7"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "10"}], "}"}]}], "}"}]}], ",", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", 
            RowBox[{"BaseStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], 
               ",", " ", 
               RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<time\>\"", ",", "\"\<concentrations\>\""}], 
              "}"}]}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], "}"}]}], 
            ",", 
            RowBox[{"PlotLabel", "\[Rule]", "\"\<x is red; y is blue\>\""}]}],
            "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                FractionBox[
                 RowBox[{
                  FractionBox[
                   RowBox[{"V1", "*", "s"}], "K1s"], 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    FractionBox[
                    RowBox[{"x", "[", "t", "]"}], 
                    RowBox[{"s", " ", "Keq1"}]]}], ")"}]}], 
                 RowBox[{"1", "+", 
                  FractionBox["s", "K1s"], "+", 
                  FractionBox[
                   RowBox[{"x", "[", "t", "]"}], "K1x"]}]], ",", 
                FractionBox[
                 RowBox[{
                  FractionBox[
                   RowBox[{"V2", "*", 
                    RowBox[{"x", "[", "t", "]"}]}], "K2x"], 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    FractionBox[
                    RowBox[{"y", "[", "t", "]"}], 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], " ", "Keq2"}]]}], ")"}]}], 
                 RowBox[{"1", "+", 
                  FractionBox[
                   RowBox[{"x", "[", "t", "]"}], "K2x"], "+", 
                  FractionBox[
                   RowBox[{"y", "[", "t", "]"}], "K2y"]}]], ",", 
                FractionBox[
                 RowBox[{
                  FractionBox[
                   RowBox[{"V3", "*", 
                    RowBox[{"y", "[", "t", "]"}]}], "K3y"], 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    FractionBox["p", 
                    RowBox[{
                    RowBox[{"y", "[", "t", "]"}], " ", "Keq3"}]]}], ")"}]}], 
                 RowBox[{"1", "+", 
                  FractionBox[
                   RowBox[{"y", "[", "t", "]"}], "K3y"], "+", 
                  FractionBox["p", "K3p"]}]]}], "}"}], "/.", "sol"}], "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", 
            RowBox[{"BaseStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"FontFamily", "\[Rule]", "\"\<Gill Sans Light\>\""}], 
               ",", " ", 
               RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<time\>\"", ",", "\"\<rates\>\""}], "}"}]}], ",", 
            RowBox[{
            "PlotLabel", "\[Rule]", 
             "\"\<v1 is red, v2 is blue, v3 is green\>\""}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"Green", ",", 
                 RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], "}"}]}], 
            ",", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "7"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "20"}], "}"}]}], "}"}]}]}], "]"}], "}"}]}], 
        "}"}], "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V1", ",", "10"}], "}"}], ",", "1", ",", "20"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K1s", ",", "1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Keq1", ",", "100"}], "}"}], ",", "1", ",", "1000"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K1x", ",", "1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V2", ",", "10"}], "}"}], ",", "1", ",", "20"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K2x", ",", "1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K2y", ",", "1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Keq2", ",", "10"}], "}"}], ",", "1", ",", "1000"}], "}"}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V3", ",", "10"}], "}"}], ",", "1", ",", "20"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K3y", ",", "1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K3p", ",", "5"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Keq3", ",", "10"}], "}"}], ",", "1", ",", "1000"}], "}"}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s", ",", "1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", "0.1"}], "}"}], ",", "0.1", ",", "10"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", "1"}], "}"}], ",", "0.1", ",", "20"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", "5"}], "}"}], ",", "0.1", ",", "20"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.474537817615508*^9, 3.4745381555139*^9}, {
  3.474538207938426*^9, 3.474538254769779*^9}, {3.474538336319669*^9, 
  3.47453843329629*^9}, {3.474538495184999*^9, 3.474538587059428*^9}, {
  3.4745386326683187`*^9, 
  3.474538668253696*^9}},ExpressionUUID->"6a8f8f93-1ae1-4e9f-82ef-\
ebe9dd172856"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`K1s$$ = 1, $CellContext`K1x$$ = 
    1, $CellContext`K2x$$ = 1, $CellContext`K2y$$ = 1, $CellContext`K3p$$ = 
    5, $CellContext`K3y$$ = 1, $CellContext`Keq1$$ = 
    100, $CellContext`Keq2$$ = 10, $CellContext`Keq3$$ = 
    10, $CellContext`p$$ = 0.1, $CellContext`s$$ = 1, $CellContext`V1$$ = 
    10, $CellContext`V2$$ = 10, $CellContext`V3$$ = 10, $CellContext`x0$$ = 
    1, $CellContext`y0$$ = 5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`V1$$], 10}, 1, 20}, {{
       Hold[$CellContext`K1s$$], 1}, 0.1, 10}, {{
       Hold[$CellContext`Keq1$$], 100}, 1, 1000}, {{
       Hold[$CellContext`K1x$$], 1}, 0.1, 10}, {{
       Hold[$CellContext`V2$$], 10}, 1, 20}, {{
       Hold[$CellContext`K2x$$], 1}, 0.1, 10}, {{
       Hold[$CellContext`K2y$$], 1}, 0.1, 10}, {{
       Hold[$CellContext`Keq2$$], 10}, 1, 1000}, {{
       Hold[$CellContext`V3$$], 10}, 1, 20}, {{
       Hold[$CellContext`K3y$$], 1}, 0.1, 10}, {{
       Hold[$CellContext`K3p$$], 5}, 0.1, 10}, {{
       Hold[$CellContext`Keq3$$], 10}, 1, 1000}, {{
       Hold[$CellContext`s$$], 1}, 0.1, 10}, {{
       Hold[$CellContext`p$$], 0.1}, 0.1, 10}, {{
       Hold[$CellContext`x0$$], 1}, 0.1, 20}, {{
       Hold[$CellContext`y0$$], 5}, 0.1, 20}}, Typeset`size$$ = {
    360., {210., 214.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`V1$5151$$ = 
    0, $CellContext`K1s$5152$$ = 0, $CellContext`Keq1$5153$$ = 
    0, $CellContext`K1x$5154$$ = 0, $CellContext`V2$5155$$ = 
    0, $CellContext`K2x$5156$$ = 0, $CellContext`K2y$5157$$ = 
    0, $CellContext`Keq2$5158$$ = 0, $CellContext`V3$5159$$ = 
    0, $CellContext`K3y$5160$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`K1s$$ = 1, $CellContext`K1x$$ = 
        1, $CellContext`K2x$$ = 1, $CellContext`K2y$$ = 1, $CellContext`K3p$$ = 
        5, $CellContext`K3y$$ = 1, $CellContext`Keq1$$ = 
        100, $CellContext`Keq2$$ = 10, $CellContext`Keq3$$ = 
        10, $CellContext`p$$ = 0.1, $CellContext`s$$ = 1, $CellContext`V1$$ = 
        10, $CellContext`V2$$ = 10, $CellContext`V3$$ = 10, $CellContext`x0$$ = 
        1, $CellContext`y0$$ = 5}, "ControllerVariables" :> {
        Hold[$CellContext`V1$$, $CellContext`V1$5151$$, 0], 
        Hold[$CellContext`K1s$$, $CellContext`K1s$5152$$, 0], 
        Hold[$CellContext`Keq1$$, $CellContext`Keq1$5153$$, 0], 
        Hold[$CellContext`K1x$$, $CellContext`K1x$5154$$, 0], 
        Hold[$CellContext`V2$$, $CellContext`V2$5155$$, 0], 
        Hold[$CellContext`K2x$$, $CellContext`K2x$5156$$, 0], 
        Hold[$CellContext`K2y$$, $CellContext`K2y$5157$$, 0], 
        Hold[$CellContext`Keq2$$, $CellContext`Keq2$5158$$, 0], 
        Hold[$CellContext`V3$$, $CellContext`V3$5159$$, 0], 
        Hold[$CellContext`K3y$$, $CellContext`K3y$5160$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Block[{$CellContext`sol}, $CellContext`sol = \
$CellContext`tsolmanipulate[$CellContext`s$$, $CellContext`V1$$, \
$CellContext`K1s$$, $CellContext`K1x$$, $CellContext`Keq1$$, \
$CellContext`V2$$, $CellContext`K2x$$, $CellContext`Keq2$$, \
$CellContext`K2y$$, $CellContext`V3$$, $CellContext`K3y$$, \
$CellContext`Keq3$$, $CellContext`K3p$$, $CellContext`x0$$, \
$CellContext`y0$$, $CellContext`p$$]; GraphicsGrid[{{
            Plot[
             Evaluate[
              ReplaceAll[{
                $CellContext`x[$CellContext`t], 
                $CellContext`y[$CellContext`t]}, $CellContext`sol]], \
{$CellContext`t, 0, 10}, PlotRange -> {{0, 7}, {0, 10}}, Frame -> True, 
             BaseStyle -> {FontFamily -> "Gill Sans Light", FontSize -> 16}, 
             FrameLabel -> {"time", "concentrations"}, PlotStyle -> {{Red, 
                Thickness[0.01]}, {Blue, 
                Thickness[0.01]}}, PlotLabel -> "x is red; y is blue"]}, {
            Plot[
             Evaluate[
              
              ReplaceAll[{($CellContext`V1$$ \
($CellContext`s$$/$CellContext`K1s$$)) ((
                  1 - $CellContext`x[$CellContext`t]/($CellContext`s$$ \
$CellContext`Keq1$$))/(
                 1 + $CellContext`s$$/$CellContext`K1s$$ + \
$CellContext`x[$CellContext`t]/$CellContext`K1x$$)), ($CellContext`V2$$ \
($CellContext`x[$CellContext`t]/$CellContext`K2x$$)) ((
                  1 - $CellContext`y[$CellContext`t]/($CellContext`x[$\
CellContext`t] $CellContext`Keq2$$))/(
                 1 + $CellContext`x[$CellContext`t]/$CellContext`K2x$$ + \
$CellContext`y[$CellContext`t]/$CellContext`K2y$$)), ($CellContext`V3$$ \
($CellContext`y[$CellContext`t]/$CellContext`K3y$$)) ((
                  1 - $CellContext`p$$/($CellContext`y[$CellContext`t] \
$CellContext`Keq3$$))/(
                 1 + $CellContext`y[$CellContext`t]/$CellContext`K3y$$ + \
$CellContext`p$$/$CellContext`K3p$$))}, $CellContext`sol]], {$CellContext`t, 
              0, 10}, Frame -> True, 
             BaseStyle -> {FontFamily -> "Gill Sans Light", FontSize -> 16}, 
             FrameLabel -> {"time", "rates"}, PlotLabel -> 
             "v1 is red, v2 is blue, v3 is green", PlotStyle -> {{Red, 
                Thickness[0.01]}, {Blue, 
                Thickness[0.01]}, {Green, 
                Thickness[0.01]}}, PlotRange -> {{0, 7}, {0, 20}}]}}]], 
      "Specifications" :> {{{$CellContext`V1$$, 10}, 1, 
         20}, {{$CellContext`K1s$$, 1}, 0.1, 10}, {{$CellContext`Keq1$$, 100},
          1, 1000}, {{$CellContext`K1x$$, 1}, 0.1, 
         10}, {{$CellContext`V2$$, 10}, 1, 20}, {{$CellContext`K2x$$, 1}, 0.1,
          10}, {{$CellContext`K2y$$, 1}, 0.1, 10}, {{$CellContext`Keq2$$, 10},
          1, 1000}, {{$CellContext`V3$$, 10}, 1, 
         20}, {{$CellContext`K3y$$, 1}, 0.1, 10}, {{$CellContext`K3p$$, 5}, 
         0.1, 10}, {{$CellContext`Keq3$$, 10}, 1, 
         1000}, {{$CellContext`s$$, 1}, 0.1, 10}, {{$CellContext`p$$, 0.1}, 
         0.1, 10}, {{$CellContext`x0$$, 1}, 0.1, 20}, {{$CellContext`y0$$, 5},
          0.1, 20}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{688., {239., 245.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.474538670088037*^9, 3.474538678633769*^9}, 
   3.600405368472186*^9},ExpressionUUID->"3e7904a7-af49-4c9f-ab06-\
f092a400249a"]
}, Open  ]]
},
WindowSize->{1089, 855},
WindowMargins->{{4, Automatic}, {Automatic, 540}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 229, 4, 38, "Text",ExpressionUUID->"0ac3f28d-2bb9-4093-bfcb-64110010a4dc"],
Cell[777, 26, 669, 10, 204, "Text",ExpressionUUID->"31c067f0-f0b3-442a-a459-d06092c0ab9c"],
Cell[1449, 38, 3843, 106, 422, "Input",ExpressionUUID->"53636d0a-a059-4b7c-9eea-5a1b59d15d92"],
Cell[5295, 146, 218, 4, 36, "Text",ExpressionUUID->"320754d7-d5eb-4b23-a617-39cf16656877"],
Cell[CellGroupData[{
Cell[5538, 154, 274, 6, 52, "Input",ExpressionUUID->"d956772e-51e5-40ec-a083-d9ec6fa87cf4"],
Cell[5815, 162, 1393, 41, 70, "Output",ExpressionUUID->"42f4d63e-7819-45e8-9937-86375327ee4b"],
Cell[7211, 205, 2096, 63, 70, "Output",ExpressionUUID->"d29c5324-1c00-4145-9038-4944620ca831"]
}, Open  ]],
Cell[9322, 271, 226, 4, 36, "Text",ExpressionUUID->"5b69a184-6a41-4a4d-84f5-96d1885d7f8b"],
Cell[CellGroupData[{
Cell[9573, 279, 447, 13, 30, "Input",ExpressionUUID->"b4f16bb4-de9b-4f81-8ecd-76b9d93c3f2d"],
Cell[10023, 294, 864, 27, 34, "Output",ExpressionUUID->"c110915d-28b0-4541-ae58-c858ca45b96f"]
}, Open  ]],
Cell[10902, 324, 223, 4, 36, "Text",ExpressionUUID->"6d6dff65-a952-4937-a551-de4afdd2e4e1"],
Cell[CellGroupData[{
Cell[11150, 332, 1361, 40, 73, "Input",ExpressionUUID->"adfdc4b0-b91a-4e2b-b930-8b2d728cd291"],
Cell[12514, 374, 23983, 402, 270, "Output",ExpressionUUID->"1dc73e5d-a5aa-403f-9ca9-1b7380102f86"]
}, Open  ]],
Cell[36512, 779, 193, 4, 36, "Text",ExpressionUUID->"f0a21c98-9f37-4a80-9867-ff5af604e80c"],
Cell[CellGroupData[{
Cell[36730, 787, 1533, 43, 73, "Input",ExpressionUUID->"f71ee0d7-2882-4837-bc54-b0e6a0c0665d"],
Cell[38266, 832, 36370, 606, 256, "Output",ExpressionUUID->"ae519512-dae6-431d-8f38-c0e62484fd3e"]
}, Open  ]],
Cell[74651, 1441, 870, 18, 108, "Text",ExpressionUUID->"816300db-572f-4938-9307-1acefac4218f"],
Cell[CellGroupData[{
Cell[75546, 1463, 676, 21, 30, "Input",ExpressionUUID->"6a311020-26eb-4cf2-938e-4ef248420e59"],
Cell[76225, 1486, 492, 13, 34, "Output",ExpressionUUID->"2d5bb626-b9fa-4fc1-93f1-fcbd76aea1c0"]
}, Open  ]],
Cell[76732, 1502, 206, 4, 36, "Text",ExpressionUUID->"20e88aac-91be-406f-be68-bc1a8e79d33c"],
Cell[CellGroupData[{
Cell[76963, 1510, 588, 17, 30, "Input",ExpressionUUID->"c374ba38-8a8d-487d-801f-92eec36c11ab"],
Cell[77554, 1529, 1887, 57, 70, "Output",ExpressionUUID->"d680aeb1-bcdf-447b-a174-bbee65ccca56"]
}, Open  ]],
Cell[79456, 1589, 245, 5, 36, "Text",ExpressionUUID->"45e13400-51e5-49bc-9494-6a5e6cce83d2"],
Cell[CellGroupData[{
Cell[79726, 1598, 1239, 38, 52, "Input",ExpressionUUID->"c42a4c21-1c78-46a5-b0c7-ded4aa05d5a4"],
Cell[80968, 1638, 454, 11, 34, "Output",ExpressionUUID->"07464a1d-672f-4c7d-872c-88c5ddc635a8"]
}, Open  ]],
Cell[81437, 1652, 209, 4, 36, "Text",ExpressionUUID->"53280295-ddaa-4d55-8bf0-36e2c006152c"],
Cell[CellGroupData[{
Cell[81671, 1660, 209, 5, 30, "Input",ExpressionUUID->"00516f28-7d10-4602-b389-e3c22f07ab56"],
Cell[81883, 1667, 421, 9, 34, "Output",ExpressionUUID->"a0d77c5d-9867-4f1a-b546-cea5271ac8db"]
}, Open  ]],
Cell[82319, 1679, 300, 6, 36, "Text",ExpressionUUID->"7302871c-b2d4-4e13-a611-0e0a3367ddb9"],
Cell[82622, 1687, 678, 10, 108, "Text",ExpressionUUID->"3ba28dc4-e03c-4217-8fe3-fa199333d78c"],
Cell[83303, 1699, 583, 16, 30, "Input",ExpressionUUID->"91d7d5c6-f9fa-47da-94dd-af5d9d733188"],
Cell[83889, 1717, 600, 17, 30, "Input",ExpressionUUID->"07a45516-6377-4533-8338-04a2bb476e33"],
Cell[84492, 1736, 1464, 43, 52, "Input",ExpressionUUID->"c296f58a-c9d0-45f9-b708-b8f33b5da697"],
Cell[85959, 1781, 330, 6, 60, "Text",ExpressionUUID->"09e174d1-b7d3-4da0-bacd-c152006ed6e0"],
Cell[CellGroupData[{
Cell[86314, 1791, 1523, 45, 94, "Input",ExpressionUUID->"d319638c-899e-4dc2-ba69-3e4cd7e240a9"],
Cell[87840, 1838, 3517, 87, 140, "Output",ExpressionUUID->"6e877e2b-4ac1-46bc-ba60-1dd1aaf3272b"],
Cell[91360, 1927, 1518, 31, 269, "Output",ExpressionUUID->"819687f4-97ff-4e49-b267-ba85538a1f4f"]
}, Open  ]],
Cell[92893, 1961, 242, 5, 84, "Text",ExpressionUUID->"e98a6ee1-d669-4d69-bd6a-116abe5662a3"],
Cell[CellGroupData[{
Cell[93160, 1970, 1103, 33, 114, "Input",ExpressionUUID->"297e4b2d-f45a-4ae0-8adf-8c0dadfeb016"],
Cell[94266, 2005, 477, 12, 34, "Output",ExpressionUUID->"0a828c9f-ca8f-49eb-aa8b-89e66df544b3"],
Cell[94746, 2019, 478, 12, 34, "Output",ExpressionUUID->"d7a622d2-49a0-4993-8b3f-0c1662237a0e"],
Cell[95227, 2033, 295, 5, 34, "Output",ExpressionUUID->"cd22476b-ed6d-4827-b0db-2ec5b03de394"]
}, Open  ]],
Cell[95537, 2041, 4257, 120, 262, "Input",ExpressionUUID->"9c543bb3-b7a7-4f2f-a2e8-e15c6a33e446"],
Cell[CellGroupData[{
Cell[99819, 2165, 271, 5, 52, "Input",ExpressionUUID->"3ad076a0-af95-4243-90b8-7a7cebf03f01"],
Cell[100093, 2172, 1358, 39, 259, "Output",ExpressionUUID->"c6f7321f-da6c-411f-a6c0-174eaef62781"],
Cell[101454, 2213, 1363, 39, 259, "Output",ExpressionUUID->"f2ac731a-8e00-4237-a85c-6e52d5bd620d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102854, 2257, 2057, 53, 115, "Input",ExpressionUUID->"8fe88e7a-52bb-4cdd-a503-2895c0e76816"],
Cell[104914, 2312, 19679, 473, 257, "Output",ExpressionUUID->"aa4b65dd-68a9-419d-baa3-1ab6a7d99922"],
Cell[124596, 2787, 19748, 474, 255, "Output",ExpressionUUID->"72f76783-f46d-4a47-80fa-75807def5df6"]
}, Open  ]],
Cell[144359, 3264, 303, 5, 36, "Text",ExpressionUUID->"80caef5f-f2a2-402b-8e17-5671933e82cd"],
Cell[144665, 3271, 323, 6, 36, "Text",ExpressionUUID->"e2c5a239-3b6b-4294-93ae-a18b59788d26"],
Cell[144991, 3279, 3305, 92, 127, "Input",ExpressionUUID->"7023f64b-f1f4-403b-8cbb-9f9eb9684d46"],
Cell[CellGroupData[{
Cell[148321, 3375, 8654, 231, 658, "Input",ExpressionUUID->"6a8f8f93-1ae1-4e9f-82ef-ebe9dd172856"],
Cell[156978, 3608, 7039, 128, 503, "Output",ExpressionUUID->"3e7904a7-af49-4c9f-ab06-f092a400249a"]
}, Open  ]]
}
]
*)

